@@ -70,8 +70,8 @@ class Debugger(BaseComponent):
         else:
             handler = reprhandler(handler)
 
-        msg = "ERROR {0:s} ({1:s}) ({2:s}): {3:s}\n".format(
-            handler, repr(fevent), repr(error_type), repr(value)
+        msg = "ERROR {} ({!r}) ({!r}): {!r}\n".format(
+            handler, fevent, error_type, value
         )
 
         s.append(msg)
