@@ -1,22 +1,18 @@
-# Package:  loader
-# Date:     16th March 2011
-# Author:   James Mills, jamesmills at comops dot com dot au
-
 """
 This module implements a generic Loader suitable for dynamically loading
 components from other modules. This supports loading from local paths,
 eggs and zip archives. Both setuptools and distribute are fully supported.
 """
-
 import sys
 from inspect import getmembers, getmodule, isclass
 
+from .components import BaseComponent
 from .handlers import handler
 from .utils import safeimport
-from .components import BaseComponent
 
 
 class Loader(BaseComponent):
+
     """Create a new Loader Component
 
     Creates a new Loader Component that enables dynamic loading of
@@ -26,7 +22,7 @@ class Loader(BaseComponent):
     channel = "loader"
 
     def __init__(self, auto_register=True, init_args=None,
-            init_kwargs=None, paths=None, channel=channel):
+                 init_kwargs=None, paths=None, channel=channel):
         "initializes x; see x.__class__.__doc__ for signature"
 
         super(Loader, self).__init__(channel=channel)
@@ -44,9 +40,8 @@ class Loader(BaseComponent):
         module = safeimport(name)
         if module is not None:
 
-            test = lambda x: isclass(x) \
-                    and issubclass(x, BaseComponent) \
-                    and getmodule(x) is module
+            def test(x):
+                return isclass(x) and issubclass(x, BaseComponent) and getmodule(x) is module
             components = [x[1] for x in getmembers(module, test)]
 
             if components:
