@@ -1,23 +1,10 @@
-# Module:   utils
-# Date:     11th April 2010
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Utils
 
 This module defines utilities used by circuits.
 """
-
-import re
 import sys
-
 from imp import reload
 
-UNCAMELRE = re.compile("([a-z0-9])([A-Z])")
-
-
-def uncamel(s):
-    return UNCAMELRE.sub("\g<1>_\g<2>", s).lower()
-
 
 def flatten(root, visited=None):
     if not visited:
@@ -51,6 +38,7 @@ def findtype(root, component, all=False):
     if components:
         return components[0]
 
+
 findcmp = findtype
 
 
@@ -68,7 +56,7 @@ def safeimport(name):
             return reload(sys.modules[name])
         else:
             return __import__(name, globals(), locals(), [""])
-    except:
+    except Exception:
         for name in sys.modules.copy():
-            if not name in modules:
+            if name not in modules:
                 del sys.modules[name]
