@@ -1,23 +1,19 @@
-# Package:  utils
-# Date:     ...
-# Author:   ...
-
-"""Utils
-
-...
-"""
-
-
 import json
 
 from circuits.core import Event
-from circuits.six import text_type
+from circuits.six import PY3, text_type
+
+META_EXCLUDE = set(dir(Event()))
+META_EXCLUDE.add("node_call_id")
+META_EXCLUDE.add("node_sock")
+META_EXCLUDE.add("node_without_result")
+META_EXCLUDE.add("success_channels")
 
 
 def load_event(s):
     data = json.loads(s)
 
-    name = "".join(x.title() for x in str(data["name"]).split("_"))
+    name = data["name"] if PY3 else data["name"].encode("utf-8")
 
     args = []
     for arg in data["args"]:
@@ -38,10 +34,17 @@ def load_event(s):
     e.notify = bool(data["notify"])
     e.channels = tuple(data["channels"])
 
+    for k, v in dict(data["meta"]).items():
+        setattr(e, k, v)
+
     return e, data["id"]
 
 
 def dump_event(e, id):
+    meta = {}
+    for name in list(set(dir(e)) - META_EXCLUDE):
+        meta[name] = getattr(e, name)
+
     data = {
         "id": id,
         "name": e.name,
@@ -50,21 +53,29 @@ def dump_event(e, id):
         "success": e.success,
         "failure": e.failure,
         "channels": e.channels,
-        "notify": e.notify
+        "notify": e.notify,
+        "meta": meta
     }
 
     return json.dumps(data)
 
 
 def dump_value(v):
+    meta = {}
+    e = v.event
+    if e:
+        for name in list(set(dir(e)) - META_EXCLUDE):
+            meta[name] = getattr(e, name)
+
     data = {
-        "id": v.node_trn,
+        "id": v.node_call_id,
         "errors": v.errors,
         "value": v._value,
+        "meta": meta
     }
     return json.dumps(data)
 
 
 def load_value(v):
     data = json.loads(v)
-    return data['value'], data['id'], data['errors']
+    return data['value'], data['id'], data['errors'], data['meta']
