@@ -1,21 +1,16 @@
-# Module:   __init__
-# Date:     3rd October 2008
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Circuits Library - Web
 
 circuits.web contains the circuits full stack web server that is HTTP
 and WSGI compliant.
 """
-
-from .utils import url
+from .controllers import BaseController, Controller, expose
+from .dispatchers import XMLRPC, Dispatcher, Static, VirtualHosts
+from .errors import forbidden, httperror, notfound, redirect
+from .events import request, response, stream
 from .loggers import Logger
-from .sessions import Sessions
-from .controllers import expose, Controller
-from .events import Request, Response
 from .servers import BaseServer, Server
-from .errors import HTTPError, Forbidden, NotFound, Redirect
-from .dispatchers import Static, Dispatcher, VirtualHosts, XMLRPC
+from .sessions import Sessions
+from .url import URL, parse_url
 
 try:
     from .dispatchers import JSONRPC
@@ -28,3 +23,4 @@ except ImportError:
     pass
 
 # flake8: noqa
+# pylama: skip=1
