@@ -21,6 +21,19 @@ Usage:
 SUPPORTED_ALGORITHM - list of supported 'Digest' algorithms
 SUPPORTED_QOP - list of supported 'Digest' 'qop'.
 """
+import time
+from hashlib import md5, sha1
+
+try:
+    from base64 import decodebytes as base64_decodebytes
+except ImportError:
+    from base64 import b64decode as base64_decodebytes  # NOQA
+
+try:
+    from urllib.request import parse_http_list, parse_keqv_list
+except ImportError:
+    from urllib2 import parse_http_list, parse_keqv_list  # NOQA
+
 __version__ = 1, 0, 1
 __author__ = "Tiago Cogumbreiro <cogumbreiro@users.sf.net>"
 __credits__ = """
@@ -33,7 +46,7 @@ __license__ = """
 Copyright (c) 2005, Tiago Cogumbreiro <cogumbreiro@users.sf.net>
 All rights reserved.
 
-Redistribution and use in source and binary forms, with or without modification,
+Redistribution and use in source and binary forms, with or without modification
 are permitted provided that the following conditions are met:
 
     * Redistributions of source code must retain the above copyright notice,
@@ -41,7 +54,7 @@ are permitted provided that the following conditions are met:
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
-    * Neither the name of Sylvain Hellegouarch nor the names of his contributors
+    * Neither the name of Sylvain Hellegouarch nor the names of his contributor
       may be used to endorse or promote products derived from this software
       without specific prior written permission.
 
@@ -61,20 +74,10 @@ __all__ = ("digestAuth", "basicAuth", "doAuth", "checkResponse",
            "parseAuthorization", "SUPPORTED_ALGORITHM", "md5SessionKey",
            "calculateNonce", "SUPPORTED_QOP")
 
-################################################################################
-import time
-try:
-    from base64 import decodebytes as base64_decodebytes
-except ImportError:
-    from base64 import b64decode as base64_decodebytes
-try:
-    from urllib.request import parse_http_list, parse_keqv_list
-except ImportError:
-    from urllib2 import parse_http_list, parse_keqv_list
-
-from hashlib import md5
+###############################################################################
 
 MD5 = "MD5"
+SHA1 = "SHA1"
 MD5_SESS = "MD5-sess"
 AUTH = "auth"
 AUTH_INT = "auth-int"
@@ -82,13 +85,13 @@ AUTH_INT = "auth-int"
 SUPPORTED_ALGORITHM = (MD5, MD5_SESS)
 SUPPORTED_QOP = (AUTH, AUTH_INT)
 
-################################################################################
+###############################################################################
 # doAuth
 #
 DIGEST_AUTH_ENCODERS = {
     MD5: lambda val: md5(val).hexdigest(),
     MD5_SESS: lambda val: md5(val).hexdigest(),
-#    SHA: lambda val: sha.new (val).hexdigest (),
+    SHA1: lambda val: sha1.new(val).hexdigest(),
 }
 
 
@@ -96,14 +99,15 @@ def calculateNonce(realm, algorithm=MD5):
     """This is an auxaliary function that calculates 'nonce' value. It is used
     to handle sessions."""
 
-    global SUPPORTED_ALGORITHM, DIGEST_AUTH_ENCODERS
     assert algorithm in SUPPORTED_ALGORITHM
 
     try:
         encoder = DIGEST_AUTH_ENCODERS[algorithm]
     except KeyError:
-        raise NotImplementedError("The chosen algorithm (%s) does not have "\
-                                   "an implementation yet" % algorithm)
+        raise NotImplementedError(
+            "The chosen algorithm (%s) does not have "
+            "an implementation yet" % algorithm
+        )
 
     s = "%d:%s" % (time.time(), realm)
     return encoder(s.encode("utf-8"))
@@ -111,7 +115,7 @@ def calculateNonce(realm, algorithm=MD5):
 
 def digestAuth(realm, algorithm=MD5, nonce=None, qop=AUTH):
     """Challenges the client for a Digest authentication."""
-    global SUPPORTED_ALGORITHM, DIGEST_AUTH_ENCODERS, SUPPORTED_QOP
+
     assert algorithm in SUPPORTED_ALGORITHM
     assert qop in SUPPORTED_QOP
 
@@ -140,7 +144,7 @@ def doAuth(realm):
     return digestAuth(realm) + " " + basicAuth(realm)
 
 
-################################################################################
+###############################################################################
 # Parse authorization parameters
 #
 def _parseDigestAuthorization(auth_params):
@@ -157,13 +161,11 @@ def _parseDigestAuthorization(auth_params):
             return None
 
     # If qop is sent then cnonce and nc MUST be present
-    if "qop" in params and not ("cnonce" in params \
-                                      and "nc" in params):
+    if "qop" in params and not ("cnonce" in params and "nc" in params):
         return None
 
     # If qop is not sent, neither cnonce nor nc can be present
-    if ("cnonce" in params or "nc" in params) and \
-       "qop" not in params:
+    if ("cnonce" in params or "nc" in params) and "qop" not in params:
         return None
 
     return params
@@ -176,6 +178,7 @@ def _parseBasicAuthorization(auth_params):
     password = password.decode("utf-8")
     return {"username": username, "password": password}
 
+
 AUTH_SCHEMES = {
     "basic": _parseBasicAuthorization,
     "digest": _parseDigestAuthorization,
@@ -187,8 +190,6 @@ def parseAuthorization(credentials):
     the HTTP header to a map itself. If the parsing fails 'None' is returned.
     """
 
-    global AUTH_SCHEMES
-
     auth_scheme, auth_params = credentials.split(" ", 1)
     auth_scheme = auth_scheme.lower()
 
@@ -203,7 +204,7 @@ def parseAuthorization(credentials):
     return params
 
 
-################################################################################
+###############################################################################
 # Check provided response for a valid password
 #
 def md5SessionKey(params, password):
@@ -277,7 +278,8 @@ def _A2(params, method, kwargs):
         raise NotImplementedError("The 'qop' method is unknown: %s" % qop)
 
 
-def _computeDigestResponse(auth_map, password, method="GET", A1=None, **kwargs):
+def _computeDigestResponse(auth_map, password, method="GET", A1=None,
+                           **kwargs):
     """
     Generates a response respecting the algorithm defined in RFC 2617
     """
@@ -349,7 +351,8 @@ def _checkDigestResponse(auth_map, password, method="GET", A1=None, **kwargs):
     return response == auth_map["response"]
 
 
-def _checkBasicResponse(auth_map, password, method='GET', encrypt=None, **kwargs):
+def _checkBasicResponse(auth_map, password, method='GET', encrypt=None,
+                        **kwargs):
     # Note that the Basic response doesn't provide the realm value so we cannot
     # test it
     try:
@@ -357,6 +360,7 @@ def _checkBasicResponse(auth_map, password, method='GET', encrypt=None, **kwargs
     except TypeError:
         return encrypt(auth_map["password"]) == password
 
+
 AUTH_RESPONSES = {
     "basic": _checkBasicResponse,
     "digest": _checkDigestResponse,
@@ -380,6 +384,8 @@ def checkResponse(auth_map, password, method="GET", encrypt=None, **kwargs):
     The 'A1' argument is only used in MD5_SESS algorithm based responses.
     Check md5SessionKey() for more info.
     """
-    global AUTH_RESPONSES
+
     checker = AUTH_RESPONSES[auth_map["auth_scheme"]]
-    return checker(auth_map, password, method=method, encrypt=encrypt, **kwargs)
+    return checker(
+        auth_map, password, method=method, encrypt=encrypt, **kwargs
+    )
