@@ -99,8 +99,8 @@ class Client(BaseComponent):
 
         # Clients MUST include Host header in HTTP/1.1 requests (RFC 2616)
         if "Host" not in headers:
-            headers["Host"] = "{0:s}{1:s}".format(
-                host, "" if port in (80, 443) else ":{0:d}".format(port)
+            headers["Host"] = "{}{}".format(
+                host, "" if port in (80, 443) else ":{:d}".format(port)
             )
 
         if body is not None:
@@ -117,7 +117,7 @@ class Client(BaseComponent):
     @handler("response")
     def _on_response(self, response):
         self._response = response
-        if response.headers.get("Connection") == "close":
+        if response.headers.get("Connection", "").lower() == "close":
             self.fire(close(), self._transport)
         return response
 
