@@ -1,17 +1,12 @@
-# Module:   constants
-# Date:     4th February 2009
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Global Constants
 
 This module implements required shared global constants.
 """
-
 from circuits import __version__
 
 SERVER_PROTOCOL = (1, 1)
-SERVER_VERSION = "circuits/%s" % __version__
-SERVER_URL = "http://bitbucket.org/prologic/circuits/"
+SERVER_VERSION = "circuits.web/%s" % __version__
+SERVER_URL = "http://circuitsweb.com/"
 
 DEFAULT_ERROR_MESSAGE = """\
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
@@ -36,13 +31,17 @@ DEFAULT_ERROR_MESSAGE = """\
   <h1>%(name)s</h1>
   %(description)s
   <pre id="traceback">%(traceback)s</pre>
-  <div id="powered_by">
-   <span>Powered by <a href="%(url)s">%(version)s</a></span>
-  </div>
+  %(powered_by)s
  </body>
 </html>
 """
 
+POWERED_BY = """
+<div id="powered_by">
+    <span>Powered by <a href="%(url)s">%(version)s</a></span>
+</div>
+"""
+
 HTTP_STATUS_CODES = {
     100: "Continue",
     101: "Switching Protocols",
