@@ -1,22 +1,14 @@
-# Module:   virtualhost
-# Date:     13th September 2007
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """VirtualHost
 
 This module implements a virtual host dispatcher that sends requests
 for configured virtual hosts to different dispatchers.
 """
-
-try:
-    from urllib.parse import urljoin
-except ImportError:
-    from urlparse import urljoin
-
-from circuits import handler, BaseComponent
+from circuits import BaseComponent, handler
+from circuits.six.moves.urllib_parse import urljoin
 
 
 class VirtualHosts(BaseComponent):
+
     """Forward to anotehr Dispatcher based on the Host header.
 
     This can be useful when running multiple sites within one server.
@@ -46,7 +38,7 @@ class VirtualHosts(BaseComponent):
 
         self.domains = domains
 
-    @handler("request", filter=True, priority=1.0)
+    @handler("request", priority=1.0)
     def _on_request(self, event, request, response):
         path = request.path.strip("/")
 
