@@ -82,7 +82,7 @@ class HTTP(BaseComponent):
         if is_unix_socket(server.host):
             url = server.host
         else:
-            url = "{0:s}://{1:s}{2:s}".format(
+            url = "{}://{}{}".format(
                 (server.secure and "https") or "http",
                 server.host or "0.0.0.0",
                 ":{0:d}".format(server.port or 80)
@@ -280,7 +280,7 @@ class HTTP(BaseComponent):
             res.close = not parser.should_keep_alive()
 
         clen = int(req.headers.get("Content-Length", "0"))
-        if clen and not parser.is_message_complete():
+        if (clen or req.headers.get("Transfer-Encoding") == "chunked") and not parser.is_message_complete():
             return
 
         if hasattr(sock, "getpeercert"):
@@ -292,6 +292,10 @@ class HTTP(BaseComponent):
         else:
             e = request(req, res)
 
+        if req.protocol != (1, 0) and not req.headers.get("Host"):
+            del self._buffers[sock]
+            return self.fire(httperror(req, res, 400, description="No host header defined"))
+
         # Guard against unwanted request paths (SECURITY).
         path = req.path
         _path = req.uri._path
