@@ -8,7 +8,7 @@
 import re
 import zlib
 
-from circuits.six import MAXSIZE, PY3, b
+from circuits.six import MAXSIZE, PY3
 from circuits.six.moves.urllib_parse import urlsplit
 
 from ..headers import Headers
@@ -75,6 +75,7 @@ class HttpParser(object):
         self.__on_message_complete = False
 
         self.__decompress_obj = None
+        self.__decompress_first_try = True
 
     def get_version(self):
         return self._version
@@ -102,16 +103,16 @@ class HttpParser(object):
 
     def recv_body(self):
         """ return last chunk of the parsed body"""
-        body = b("").join(self._body)
+        body = b"".join(self._body)
         self._body = []
         self._partial_body = False
         return body
 
     def recv_body_into(self, barray):
-        """ Receive the last chunk of the parsed bodyand store the data
+        """ Receive the last chunk of the parsed body and store the data
         in a buffer rather than creating a new string. """
         length = len(barray)
-        body = b("").join(self._body)
+        body = b"".join(self._body)
         m = min(len(body), length)
         data, rest = body[:m], body[m:]
         barray[0:m] = data
@@ -125,7 +126,9 @@ class HttpParser(object):
     def is_upgrade(self):
         """ Do we get upgrade header in the request. Useful for
         websockets """
-        return self._headers.get('connection', "").lower() == "upgrade"
+        hconn = self._headers.get('connection', "").lower()
+        hconn_parts = [x.strip() for x in hconn.split(',')]
+        return "upgrade" in hconn_parts
 
     def is_headers_complete(self):
         """ return True if all headers have been parsed. """
@@ -161,27 +164,27 @@ class HttpParser(object):
         # end of body can be passed manually by putting a length of 0
 
         if length == 0:
-            self.on_message_complete = True
+            self.__on_message_complete = True
             return length
 
         # start to parse
         nb_parsed = 0
         while True:
             if not self.__on_firstline:
-                idx = data.find(b("\r\n"))
+                idx = data.find(b"\r\n")
                 if idx < 0:
                     self._buf.append(data)
                     return len(data)
                 else:
                     self.__on_firstline = True
                     self._buf.append(data[:idx])
-                    first_line = b("").join(self._buf)
+                    first_line = b"".join(self._buf)
                     if PY3:
                         first_line = str(first_line, 'unicode_escape')
                     nb_parsed = nb_parsed + idx + 2
 
                     rest = data[idx + 2:]
-                    data = b("")
+                    data = b""
                     if self._parse_firstline(first_line):
                         self._buf = [rest]
                     else:
@@ -189,12 +192,13 @@ class HttpParser(object):
             elif not self.__on_headers_complete:
                 if data:
                     self._buf.append(data)
-                    data = b("")
+                    data = b""
 
                 try:
-                    to_parse = b("").join(self._buf)
+                    to_parse = b"".join(self._buf)
                     ret = self._parse_headers(to_parse)
-                    if not ret:
+
+                    if ret is False:
                         return length
                     nb_parsed = nb_parsed + (len(to_parse) - ret)
                 except InvalidHeader as e:
@@ -207,7 +211,7 @@ class HttpParser(object):
 
                 if data:
                     self._buf.append(data)
-                    data = b("")
+                    data = b""
 
                 ret = self._parse_body()
                 if ret is None:
@@ -255,7 +259,7 @@ class HttpParser(object):
         # status
         matchs = STATUS_RE.match(bits[1])
         if matchs is None:
-            raise InvalidRequestLine("Invalid status: {0:s}".format(bits[1]))
+            raise InvalidRequestLine("Invalid status: {!r}".format(bits[1]))
 
         self._status = bits[1]
         self._status_code = int(matchs.group(1))
@@ -289,7 +293,7 @@ class HttpParser(object):
         self._version = (int(match.group(1)), int(match.group(2)))
 
         # update environ
-        if hasattr(self, 'environ'):
+        if hasattr(self, '_environ'):
             self._environ.update({
                 "PATH_INFO": self._path,
                 "QUERY_STRING": self._query_string,
@@ -298,23 +302,22 @@ class HttpParser(object):
                 "SERVER_PROTOCOL": bits[2]})
 
     def _parse_headers(self, data):
-        if self._version == (1, 0):
-            idx = data.find(b("\r\n"))
-            if idx < 0:  # an empty line is required
-                return False
-            if idx == 0:  # we don't have all headers
-                rest = data[2:]
-                self._buf = [rest]
-                self.__on_headers_complete = True
-                return len(rest)
-
-        idx = data.find((b"\r\n\r\n"))
+        if data == b'\r\n':
+            self.__on_headers_complete = True
+            self._buf = []
+            return 0
+        idx = data.find(b"\r\n\r\n")
         if idx < 0:  # we don't have all headers
-            raise InvalidHeader("No host header defined")
+            if self._status_code == 204 and data == b"\r\n":
+                self._buf = []
+                self.__on_headers_complete = True
+                return 0
+            else:
+                return False
 
         # Split lines on \r\n keeping the \r\n on each line
         lines = [(str(line, 'unicode_escape') if PY3 else line) + "\r\n"
-                 for line in data[:idx].split(b("\r\n"))]
+                 for line in data[:idx].split(b"\r\n")]
 
         # Parse headers into key/value pairs paying attention
         # to continuation lines.
@@ -327,11 +330,18 @@ class HttpParser(object):
             name = name.rstrip(" \t").upper()
             if HEADER_RE.search(name):
                 raise InvalidHeader("invalid header name %s" % name)
+
+            if value.endswith("\r\n"):
+                value = value[:-2]
+
             name, value = name.strip(), [value.lstrip()]
 
             # Consume value continuation lines
             while len(lines) and lines[0].startswith((" ", "\t")):
-                value.append(lines.pop(0))
+                curr = lines.pop(0)
+                if curr.endswith("\r\n"):
+                    curr = curr[:-2]
+                value.append(curr)
             value = ''.join(value).rstrip()
 
             # store new header value
@@ -360,6 +370,7 @@ class HttpParser(object):
         if self.decompress:
             if encoding == "gzip":
                 self.__decompress_obj = zlib.decompressobj(16 + zlib.MAX_WBITS)
+                self.__decompress_first_try = False
             elif encoding == "deflate":
                 self.__decompress_obj = zlib.decompressobj()
 
@@ -369,13 +380,28 @@ class HttpParser(object):
         return len(rest)
 
     def _parse_body(self):
-        if not self._chunked:
-            body_part = b("").join(self._buf)
+        if self._status_code == 204 and len(self._buf) == 0:
+            self.__on_message_complete = True
+            return
+        elif not self._chunked:
+            body_part = b"".join(self._buf)
+            if not body_part and self._clen is None:
+                if not self._status:  # message complete only for servers
+                    self.__on_message_complete = True
+                return
             self._clen_rest -= len(body_part)
 
             # maybe decompress
             if self.__decompress_obj is not None:
-                body_part = self.__decompress_obj.decompress(body_part)
+                if not self.__decompress_first_try:
+                    body_part = self.__decompress_obj.decompress(body_part)
+                else:
+                    try:
+                        body_part = self.__decompress_obj.decompress(body_part)
+                    except zlib.error:
+                        self.__decompress_obj.decompressobj = zlib.decompressobj(-zlib.MAX_WBITS)
+                        body_part = self.__decompress_obj.decompress(body_part)
+                    self.__decompress_first_try = False
 
             self._partial_body = True
             self._body.append(body_part)
@@ -385,7 +411,7 @@ class HttpParser(object):
                 self.__on_message_complete = True
             return
         else:
-            data = b("").join(self._buf)
+            data = b"".join(self._buf)
             try:
 
                 size, rest = self._parse_chunk_size(data)
@@ -417,11 +443,11 @@ class HttpParser(object):
             return len(rest)
 
     def _parse_chunk_size(self, data):
-        idx = data.find(b("\r\n"))
+        idx = data.find(b"\r\n")
         if idx < 0:
             return None, None
         line, rest_chunk = data[:idx], data[idx + 2:]
-        chunk_size = line.split(b(";"), 1)[0].strip()
+        chunk_size = line.split(b";", 1)[0].strip()
         try:
             chunk_size = int(chunk_size, 16)
         except ValueError:
@@ -433,7 +459,7 @@ class HttpParser(object):
         return chunk_size, rest_chunk
 
     def _parse_trailers(self, data):
-        idx = data.find(b("\r\n\r\n"))
+        idx = data.find(b"\r\n\r\n")
 
-        if data[:2] == b("\r\n"):
+        if data[:2] == b"\r\n":
             self._trailers = self._parse_headers(data[:idx])
