@@ -1,33 +1,46 @@
-# Module:   utils
-# Date:     13th September 2007
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Utilities
 
 This module implements utility functions.
 """
-
+import os
 import re
-import zlib
-import time
+import stat
 import struct
-from io import TextIOWrapper
+import time
+import zlib
 from cgi import FieldStorage
+from io import TextIOWrapper
+from math import sqrt
 
-try:
-    from urllib.parse import urljoin as _urljoin
-except ImportError:
-    from urlparse import urljoin as _urljoin  # NOQA
+from circuits.net.utils import is_ssl_handshake  # noqa
+from circuits.six.moves.urllib_parse import parse_qs as _parse_qs
 
-try:
-    from urllib.parse import parse_qs as _parse_qs
-except ImportError:
-    from cgi import parse_qs as _parse_qs  # NOQA
-
-from .exceptions import RequestEntityTooLarge
+from .exceptions import RangeUnsatisfiable, RequestEntityTooLarge
 
 quoted_slash = re.compile("(?i)%2F")
-image_map_pattern = re.compile("[0-9]+,[0-9]+")
+image_map_pattern = re.compile("^[0-9]+,[0-9]+$")
+
+
+def is_unix_socket(path):
+    if not os.path.exists(path):
+        return False
+
+    mode = os.stat(path).st_mode
+
+    return stat.S_ISSOCK(mode)
+
+
+def average(xs):
+    return sum(xs) * 1.0 / len(xs)
+
+
+def variance(xs):
+    avg = average(xs)
+    return list(map(lambda x: (x - avg) ** 2, xs))
+
+
+def stddev(xs):
+    return sqrt(average(variance(xs)))
 
 
 def parse_body(request, response, params):
@@ -37,7 +50,7 @@ def parse_body(request, response, params):
     try:
         form = FieldStorage(
             environ={"REQUEST_METHOD": "POST"},
-            fp=request.body,
+            fp=TextIOWrapper(request.body),
             headers=request.headers,
             keep_blank_values=True
         )
@@ -124,95 +137,6 @@ def compress(body, compress_level):
         + struct.pack("<L", size & 0xFFFFFFFF)
 
 
-def url(request, path="", qs="", script_name=None, base=None, relative=None):
-    """Create an absolute URL for the given path.
-
-    If 'path' starts with a slash ('/'), this will return
-       - (base + script_name + path + qs).
-    If it does not start with a slash, this returns
-       - (base + script_name [+ request.path] + path + qs).
-
-    If script_name is None, request will be used
-    to find a script_name, if available.
-
-    If base is None, request.base will be used (if available).
-
-    Finally, note that this function can be used to obtain an absolute URL
-    for the current request path (minus the querystring) by passing no args.
-    If you call url(qs=request.qs), you should get the
-    original browser URL (assuming no internal redirections).
-
-    If relative is False the output will be an absolute URL
-    (including the scheme, host, vhost, and script_name).
-    If True, the output will instead be a URL that is relative to the
-    current request path, perhaps including '..' atoms. If relative is
-    the string 'server', the output will instead be a URL that is
-    relative to the server root; i.e., it will start with a slash.
-    """
-    if qs:
-        qs = '?' + qs
-
-    if not path.startswith("/"):
-        # Append/remove trailing slash from request.path as needed
-        # (this is to support mistyped URL's without redirecting;
-        # if you want to redirect, use tools.trailing_slash).
-        pi = request.path
-        if request.index is True:
-            if not pi.endswith('/'):
-                pi = pi + '/'
-        elif request.index is False:
-            if pi.endswith('/') and pi != '/':
-                pi = pi[:-1]
-
-        if path == "":
-            path = pi
-        else:
-            path = _urljoin(pi, path)
-
-    if script_name is None:
-        script_name = request.script_name
-    if base is None:
-        base = request.base
-
-    newurl = base + script_name + path + qs
-
-    if './' in newurl:
-        # Normalize the URL by removing ./ and ../
-        atoms = []
-        for atom in newurl.split('/'):
-            if atom == '.':
-                pass
-            elif atom == '..':
-                atoms.pop()
-            else:
-                atoms.append(atom)
-        newurl = '/'.join(atoms)
-
-    # At this point, we should have a fully-qualified absolute URL.
-
-    # See http://www.ietf.org/rfc/rfc2396.txt
-    if relative == 'server':
-        # "A relative reference beginning with a single slash character is
-        # termed an absolute-path reference, as defined by <abs_path>..."
-        # This is also sometimes called "server-relative".
-        newurl = '/' + '/'.join(newurl.split('/', 3)[3:])
-    elif relative:
-        # "A relative reference that does not begin with a scheme name
-        # or a slash character is termed a relative-path reference."
-        old = url().split('/')[:-1]
-        new = newurl.split('/')
-        while old and new:
-            a, b = old[0], new[0]
-            if a != b:
-                break
-            old.pop(0)
-            new.pop(0)
-        new = (['..'] * len(old)) + new
-        newurl = '/'.join(new)
-
-    return newurl
-
-
 def get_ranges(headervalue, content_length):
     """Return a list of (start, stop) indices from a Range header, or None.
 
@@ -253,12 +177,24 @@ def get_ranges(headervalue, content_length):
                 # did not exist. (Normally, this means return a 200
                 # response containing the full entity)."
                 return None
-            result.append((start, stop + 1))
+            # Prevent duplicate ranges. See Issue #59
+            if (start, stop + 1) not in result:
+                result.append((start, stop + 1))
         else:
             if not stop:
                 # See rfc quote above.
                 return None
             # Negative subscript (last N bytes)
-            result.append((content_length - int(stop), content_length))
+            # Prevent duplicate ranges. See Issue #59
+            if (content_length - int(stop), content_length) not in result:
+                result.append((content_length - int(stop), content_length))
+
+    # Can we satisfy the requested Range?
+    # If we have an exceedingly high standard deviation
+    # of Range(s) we reject the request.
+    # See Issue #59
+
+    if len(result) > 1 and stddev([x[1] - x[0] for x in result]) > 2.0:
+        raise RangeUnsatisfiable()
 
     return result
