@@ -1,6 +1,7 @@
 import base64
 import os
 import random
+import re
 from errno import ECONNRESET
 from socket import error as SocketError
 
@@ -55,6 +56,7 @@ class WebSocketClient(BaseComponent):
         self._response = None
         self._pending = 0
         self._wschannel = wschannel
+        self._codec = None
 
         self._transport = TCPClient(channel=self.channel).register(self)
         HTTP(channel=self.channel).register(self._transport)
@@ -95,7 +97,9 @@ class WebSocketClient(BaseComponent):
         headers[
             "Sec-WebSocket-Key"] = base64.b64encode(sec_key).decode("latin1")
         headers["Sec-WebSocket-Version"] = "13"
-        command = "GET %s HTTP/1.1" % self._resource
+        UNSAFE_CHARS = re.compile('[^0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~]')
+        escaped_resource = UNSAFE_CHARS.sub('', self._resource.encode('ASCII', 'replace').decode('ASCII'))
+        command = "GET %s HTTP/1.1" % (escaped_resource,)
         message = "%s\r\n%s" % (command, headers)
         self._pending += 1
         self.fire(write(message.encode('utf-8')), self._transport)
@@ -105,13 +109,26 @@ class WebSocketClient(BaseComponent):
     def _on_response(self, response):
         self._response = response
         self._pending -= 1
-        if response.headers.get("Connection") == "Close" \
+        if response.headers.get("Connection", "").lower() == "close" \
                 or response.status != 101:
             self.fire(close(), self._transport)
             raise NotConnected()
-        WebSocketCodec(
+        self._codec = WebSocketCodec(
             data=response.body.read(), channel=self._wschannel).register(self)
 
+    @handler('read')
+    def _on_read(self, event, *args):
+        # FIXME: every read-event is lost due to a race condition between
+        # WebSocketCodec().register() and the registered()-event of that instance.
+        if len(args) != 1:
+            return
+        if self._codec is not None and self._codec.parent is self:
+            if 'read' not in self._codec.events():
+                event.stop()
+                self.fire(event.create('read', *args))
+            else:
+                self.removeHandler(self._on_read)
+
     @handler("error", priority=10)
     def _on_error(self, event, error, *args, **kwargs):
         # For HTTP 1.1 we leave the connection open. If the peer closes
