@@ -1,33 +1,24 @@
-# Module:   wsgi
-# Date:     6th November 2008
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """WSGI Components
 
 This module implements WSGI Components.
 """
-
-try:
-    from urllib.parse import unquote
-except ImportError:
-    from urllib import unquote  # NOQA
-
 from operator import itemgetter
-from traceback import format_tb
 from sys import exc_info as _exc_info
+from traceback import format_tb
+from types import GeneratorType
 
+from circuits.core import BaseComponent, handler
 from circuits.tools import tryimport
-from circuits.core import handler, BaseComponent
+from circuits.web import wrappers
+
+from .dispatchers import Dispatcher
+from .errors import httperror
+from .events import request
+from .headers import Headers
+from .http import HTTP
 
 StringIO = tryimport(("cStringIO", "StringIO", "io"), "StringIO")
 
-from . import wrappers
-from .http import HTTP
-from .events import Request
-from .headers import Headers
-from .errors import HTTPError
-from .dispatchers import Dispatcher
-
 
 def create_environ(errors, path, req):
     environ = {}
@@ -36,7 +27,7 @@ def create_environ(errors, path, req):
     env("REQUEST_METHOD", req.method)
     env("SERVER_NAME", req.host.split(":", 1)[0])
     env("SERVER_PORT", "%i" % (req.server.port or 0))
-    env("SERVER_PROTOCOL", "HTTP/%d.%d" % req.server_protocol)
+    env("SERVER_PROTOCOL", "HTTP/%d.%d" % req.server.http.protocol)
     env("QUERY_STRING", req.qs)
     env("SCRIPT_NAME", req.script_name)
     env("CONTENT_TYPE", req.headers.get("Content-Type", ""))
@@ -78,7 +69,7 @@ class Application(BaseComponent):
     def init(self):
         self._finished = False
 
-        HTTP().register(self)
+        HTTP(self).register(self)
         Dispatcher().register(self)
 
     def translateHeaders(self, environ):
@@ -97,41 +88,39 @@ class Application(BaseComponent):
         headers = Headers(list(self.translateHeaders(environ)))
 
         protocol = tuple(map(int, env("SERVER_PROTOCOL")[5:].split(".")))
-        request = wrappers.Request(
+        req = wrappers.Request(
             None,
             env("REQUEST_METHOD"),
             env("wsgi.url_scheme"),
             env("PATH_INFO", ""),
             protocol,
-            env("QUERY_STRING", "")
+            env("QUERY_STRING", ""),
+            headers=headers
         )
-        request.server = None
 
-        request.remote = wrappers.Host(env("REMOTE_ADDR"), env("REMTOE_PORT"))
-
-        request.headers = headers
-        request.script_name = env("SCRIPT_NAME")
-        request.wsgi_environ = environ
+        req.remote = wrappers.Host(env("REMOTE_ADDR"), env("REMTOE_PORT"))
+        req.script_name = env("SCRIPT_NAME")
+        req.wsgi_environ = environ
 
         try:
             cl = int(headers.get("Content-Length", "0"))
-        except:
+        except ValueError:
             cl = 0
 
-        request.body.write(env("wsgi.input").read(cl))
-        request.body.seek(0)
+        req.body.write(env("wsgi.input").read(cl))  # FIXME: what about chunked encoding?
+        req.body.seek(0)
 
-        response = wrappers.Response(request)
-        response.gzip = "gzip" in request.headers.get("Accept-Encoding", "")
+        res = wrappers.Response(req)
+        res.gzip = "gzip" in req.headers.get("Accept-Encoding", "")
 
-        return request, response
+        return req, res
 
     def __call__(self, environ, start_response, exc_info=None):
         self.request, self.response = self.getRequestResponse(environ)
-        self.fire(Request(self.request, self.response))
+        self.fire(request(self.request, self.response))
 
         self._finished = False
-        while self or not self._finished:
+        while self._queue or not self._finished:
             self.tick()
 
         self.response.prepare()
@@ -139,13 +128,25 @@ class Application(BaseComponent):
         status = self.response.status
         headers = list(self.response.headers.items())
 
-        start_response(status, headers, exc_info)
+        start_response(str(status), headers, exc_info)
         return body
 
-    @handler("response", filter=True, channel="web")
-    def response(self, response):
+    @handler("response", channel="web")
+    def on_response(self, event, response):
         self._finished = True
-        return True
+        event.stop()
+
+    @property
+    def host(self):
+        return ""
+
+    @property
+    def port(self):
+        return 0
+
+    @property
+    def secure(self):
+        return False
 
 
 class _Empty(str):
@@ -155,6 +156,7 @@ class _Empty(str):
 
     __nonzero__ = __bool__
 
+
 empty = _Empty()
 del _Empty
 
@@ -168,12 +170,12 @@ class Gateway(BaseComponent):
 
         self.errors = dict((k, StringIO()) for k in self.apps.keys())
 
-    @handler("request", filter=True, priority=0.2)
-    def _on_request(self, event, request, response):
+    @handler("request", priority=0.2)
+    def _on_request(self, event, req, res):
         if not self.apps:
             return
 
-        parts = request.path.split("/")
+        parts = req.path.split("/")
 
         candidates = []
         for i in range(len(parts)):
@@ -190,19 +192,24 @@ class Gateway(BaseComponent):
         buffer = StringIO()
 
         def start_response(status, headers, exc_info=None):
-            response.code = int(status.split(" ", 1)[0])
+            res.status = int(status.split(" ", 1)[0])
             for header in headers:
-                response.headers.add_header(*header)
+                res.headers.add_header(*header)
             return buffer.write
 
         errors = self.errors[path]
 
-        environ = create_environ(errors, path, request)
+        environ = create_environ(errors, path, req)
 
         try:
             body = app(environ, start_response)
             if isinstance(body, list):
-                body = "".join(body)
+                _body = type(body[0])() if body else ""
+                body = _body.join(body)
+            elif isinstance(body, GeneratorType):
+                res.body = body
+                res.stream = True
+                return res
 
             if not body:
                 if not buffer.tell():
@@ -215,4 +222,6 @@ class Gateway(BaseComponent):
         except Exception as error:
             etype, evalue, etraceback = _exc_info()
             error = (etype, evalue, format_tb(etraceback))
-            return HTTPError(request, response, 500, error=error)
+            return httperror(req, res, 500, error=error)
+        finally:
+            event.stop()
