@@ -1,16 +1,12 @@
 #!/usr/bin/env python
-
-
 """Clone of the standard UNIX "cat" command.
 
 This example shows how you can utilize some of the buitlin I/O components
 in circuits to write a very simple clone of the standard UNIX "cat" command.
 """
-
-
 import sys
 
-from circuits.io import stdout, File, write
+from circuits.io import File, stdout, write
 
 
 class Cat(File):
@@ -36,5 +32,6 @@ class Cat(File):
 
         raise SystemExit(0)
 
+
 # Start and "run" the system.
 Cat(sys.argv[1]).run()
