@@ -1,10 +1,9 @@
 #!/usr/bin/env python
+from __future__ import print_function
 
 from time import sleep
 
-
-from circuits import task, Worker
-from circuits import Component, Debugger, Event, Timer
+from circuits import Component, Debugger, Event, Timer, Worker, task
 
 
 def factorial(n):
@@ -29,6 +28,7 @@ class App(Component):
         print("{0:d}".format(x.value))
         self.stop()
 
+
 app = App()
 Debugger().register(app)
 app.run()
