@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-
 """IRC Bot Example
 
 This example shows how to use several components in circuits as well
@@ -7,14 +6,14 @@ as one of the builtin networking protocols. This IRC Bot simply connects
 to the FreeNode IRC Network and joins the #circuits channel. It will also
 echo anything privately messages to it in response.
 """
+import sys
 
-
-from circuits import Component
-from circuits.net.sockets import TCPClient, Connect
-from circuits.net.protocols.irc import IRC, PRIVMSG, USER, NICK, JOIN
-
-from circuits.net.protocols.irc import ERR_NICKNAMEINUSE
-from circuits.net.protocols.irc import RPL_ENDOFMOTD, ERR_NOMOTD
+from circuits import Component, Debugger
+from circuits.net.sockets import TCPClient, connect
+from circuits.protocols.irc import (
+    ERR_NICKNAMEINUSE, ERR_NOMOTD, IRC, JOIN, NICK, PRIVMSG, RPL_ENDOFMOTD,
+    USER,
+)
 
 
 class Bot(Component):
@@ -22,9 +21,9 @@ class Bot(Component):
     # Define a separate channel so we can create many instances of ``Bot``
     channel = "ircbot"
 
-    def init(self, host, port=6667, channel=channel):
+    def init(self, host="irc.freenode.net", port="6667", channel=channel):
         self.host = host
-        self.port = port
+        self.port = int(port)
 
         # Add TCPClient and IRC to the system.
         TCPClient(channel=self.channel).register(self)
@@ -37,19 +36,28 @@ class Bot(Component):
         when it is ready to start making a new connection.
         """
 
-        self.fire(Connect(self.host, self.port))
+        self.fire(connect(self.host, self.port))
 
     def connected(self, host, port):
-        """Connected Event
+        """connected Event
 
         This event is triggered by the underlying ``TCPClient`` Component
         when a successfully connection has been made.
         """
 
-        self.fire(USER("circuits", host, host, "Test circuits IRC Bot"))
         self.fire(NICK("circuits"))
+        self.fire(USER("circuits", "circuits", host, "Test circuits IRC Bot"))
 
-    def numeric(self, source, target, numeric, args, message):
+    def disconnected(self):
+        """disconnected Event
+
+        This event is triggered by the underlying ``TCPClient`` Component
+        when the connection is lost.
+        """
+
+        raise SystemExit(0)
+
+    def numeric(self, source, numeric, *args):
         """Numeric Event
 
         This event is triggered by the ``IRC`` Protocol Component when we have
@@ -57,24 +65,29 @@ class Bot(Component):
         """
 
         if numeric == ERR_NICKNAMEINUSE:
-            self.fire(NICK("%s_" % args))
-        if numeric in (RPL_ENDOFMOTD, ERR_NOMOTD):
+            self.fire(NICK("{0:s}_".format(args[0])))
+        elif numeric in (RPL_ENDOFMOTD, ERR_NOMOTD):
             self.fire(JOIN("#circuits"))
 
-    def message(self, source, target, message):
+    def privmsg(self, source, target, message):
         """Message Event
 
         This event is triggered by the ``IRC`` Protocol Component for each
         message we receieve from the server.
         """
 
-        self.fire(PRIVMSG(source[0], message))
+        if target.startswith("#"):
+            self.fire(PRIVMSG(target, message))
+        else:
+            self.fire(PRIVMSG(source[0], message))
 
 
 # Configure and run the system
-bot = Bot("irc.freenode.net")
+bot = Bot(*sys.argv[1:])
+
+Debugger().register(bot)
 
 # To register a 2nd ``Bot`` instance. Simply use a separate channel.
-#Bot("irc.freenode.net", channel="foo").register(bot)
+# Bot(*sys.argv[1:], channel="foo").register(bot)
 
 bot.run()
