@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """Example IRC Client
 
 A basic IRC client with a very basic console interface.
@@ -10,16 +9,17 @@ For usage type:
    ./ircclient.py --help
 
 """
+from __future__ import print_function
 
 import os
-from socket import gethostname
 from optparse import OptionParser
+from socket import gethostname
 
+from circuits import Component, Debugger, __version__ as systemVersion, handler
 from circuits.io import stdin
-from circuits import handler, Component
-from circuits import __version__ as systemVersion
-from circuits.net.sockets import TCPClient, Connect
-from circuits.net.protocols.irc import IRC, PRIVMSG, USER, NICK, JOIN
+from circuits.net.events import connect
+from circuits.net.sockets import TCPClient
+from circuits.protocols.irc import IRC, JOIN, NICK, PRIVMSG, USER
 
 USAGE = "%prog [options] host [port]"
 VERSION = "%prog v" + systemVersion
@@ -34,6 +34,12 @@ def parse_options():
         help="Nickname to use"
     )
 
+    parser.add_option(
+        "-d", "--debug",
+        action="store_true", default=False, dest="debug",
+        help="Enable debug verbose logging",
+    )
+
     parser.add_option(
         "-c", "--channel",
         action="store", default="#circuits", dest="channel",
@@ -67,17 +73,21 @@ class Client(Component):
         TCPClient(channel=self.channel).register(self)
         IRC(channel=self.channel).register(self)
 
+        # Enable Debugging?
+        if opts.debug:
+            Debugger().register(self)
+
     def ready(self, component):
-        """Ready Event
+        """ready Event
 
         This event is triggered by the underlying ``TCPClient`` Component
         when it is ready to start making a new connection.
         """
 
-        self.fire(Connect(self.host, self.port))
+        self.fire(connect(self.host, self.port))
 
     def connected(self, host, port):
-        """Connected Event
+        """connected Event
 
         This event is triggered by the underlying ``TCPClient`` Component
         when a successfully connection has been made.
@@ -89,11 +99,22 @@ class Client(Component):
         hostname = self.hostname
         name = "%s on %s using circuits/%s" % (nick, hostname, systemVersion)
 
-        self.fire(USER(nick, hostname, host, name))
         self.fire(NICK(nick))
+        self.fire(USER(nick, nick, self.hostname, name))
 
-    def numeric(self, source, target, numeric, args, message):
-        """Numeric Event
+    def disconnected(self):
+        """disconnected Event
+
+        This event is triggered by the underlying ``TCPClient`` Component
+        when the connection has been disconnected.
+        """
+
+        print("Disconnecetd from %s:%d" % (self.host, self.port))
+
+        raise SystemExit(0)
+
+    def numeric(self, source, numeric, *args):
+        """numeric Event
 
         This event is triggered by the ``IRC`` Protocol Component when we have
         received an IRC Numberic Event from server we are connected to.
@@ -106,7 +127,7 @@ class Client(Component):
             self.fire(NICK(newnick))
 
     def join(self, source, channel):
-        """Join Event
+        """join Event
 
         This event is triggered by the ``IRC`` Protocol Component when a
         user has joined a channel.
@@ -115,10 +136,14 @@ class Client(Component):
         if source[0].lower() == self.nick.lower():
             print("Joined %s" % channel)
         else:
-            print("--> %s (%s) has joined %s" % (source[0], source, channel))
+            print(
+                "--> %s (%s) has joined %s" % (
+                    source[0], "@".join(source[1:]), channel
+                )
+            )
 
     def notice(self, source, target, message):
-        """Notice Event
+        """notice Event
 
         This event is triggered by the ``IRC`` Protocol Component for each
         notice we receieve from the server.
@@ -126,28 +151,31 @@ class Client(Component):
 
         print("-%s- %s" % (source[0], message))
 
-    def message(self, source, target, message):
-        """Message Event
+    def privmsg(self, source, target, message):
+        """privmsg Event
 
         This event is triggered by the ``IRC`` Protocol Component for each
         message we receieve from the server.
         """
 
         if target[0] == "#":
-            print("<%s> %s" % (target, message))
+            print("<%s> %s" % (source[0], message))
         else:
-            print("-%s- %s" % (source, message))
+            print("-%s- %s" % (source[0], message))
 
     @handler("read", channel="stdin")
     def stdin_read(self, data):
-        """Read Event (on channel ``stdin``)
+        """read Event (on channel ``stdin``)
 
         This is the event handler for ``read`` events specifically from the
         ``stdin`` channel. This is triggered each time stdin has data that
         it has read.
         """
 
-        self.fire(PRIVMSG(self.ircchannel, data.strip()))
+        data = data.strip().decode("utf-8")
+
+        print("<{0:s}> {1:s}".format(self.nick, data))
+        self.fire(PRIVMSG(self.ircchannel, data))
 
 
 def main():
