@@ -1,18 +1,20 @@
 #!/usr/bin/env python
-
 from circuits import Component, Event
 
 
-class Hello(Event):
-    """Hello Event"""
+class hello(Event):
+
+    """hello Event"""
 
 
-class Foo(Event):
-    """Foo Event"""
+class foo(Event):
+
+    """foo Event"""
 
 
-class Bar(Event):
-    """Bar Event"""
+class bar(Event):
+
+    """bar Event"""
 
 
 class App(Component):
@@ -24,13 +26,14 @@ class App(Component):
         return 2
 
     def hello(self):
-        x = yield self.call(Foo())
-        y = yield self.call(Bar())
+        x = yield self.call(foo())
+        y = yield self.call(bar())
         yield x.value + y.value
 
     def started(self, component):
-        x = yield self.call(Hello())
+        x = yield self.call(hello())
         print("{0:d}".format(x.value))
         self.stop()
 
+
 App().run()
