@@ -1,18 +1,20 @@
 #!/usr/bin/env python
-
 from circuits import Component, Event
 
 
-class Hello(Event):
-    """Hello Event"""
+class hello(Event):
+
+    """hello Event"""
 
 
-class Foo(Event):
-    """Foo Event"""
+class foo(Event):
+
+    """foo Event"""
 
 
-class Bar(Event):
-    """Bar Event"""
+class bar(Event):
+
+    """bar Event"""
 
 
 class App(Component):
@@ -24,18 +26,19 @@ class App(Component):
         return 2
 
     def hello(self):
-        x = self.fire(Foo())
+        x = self.fire(foo())
         yield self.wait("foo")
 
-        y = self.fire(Bar())
+        y = self.fire(bar())
         yield self.wait("bar")
 
         yield x.value + y.value
 
     def started(self, component):
-        x = self.fire(Hello())
+        x = self.fire(hello())
         yield self.wait("hello")
         print("{0:d}".format(x.value))
         self.stop()
 
+
 App().run()
