@@ -1,14 +1,13 @@
 #!/usr/bin/env python
-
 """Clone of the standard UNIX "tail" command.
 
 This example shows how you can utilize some of the buitlin I/O components
 in circuits to write a very simple clone of the standard UNIX "tail" command.
 """
-
 import sys
+
 from circuits import Component, Debugger
-from circuits.io import stdout, File, Write
+from circuits.io import File, Write, stdout
 
 
 class Tail(Component):
@@ -38,5 +37,6 @@ class Tail(Component):
 
         self.fire(Write(data), self.stdout)
 
+
 # Setup and run the system.
 (Tail(sys.argv[1]) + Debugger()).run()
