@@ -1,16 +1,15 @@
 #!/usr/bin/env python
-
-from circuits import handler, Component
+from circuits import Component, handler
+from circuits.web import Controller, Server
 from circuits.web.errors import Forbidden
-from circuits.web import Server, Controller
 
 
 class ACL(Component):
 
     allowed = ["127.0.0.1"]
 
-    @handler("request", filter=True, priority=1.0)
-    def on_request(self, request, response):
+    @handler("request", priority=1.0)
+    def on_request(self, event, request, response):
         """Filter Requests applying IP based Authorization
 
         Filter any incoming requests at a higher priority than the
@@ -19,7 +18,8 @@ class ACL(Component):
         match the allowed set.
         """
 
-        if not request.remote.ip in self.allowed:
+        if request.remote.ip not in self.allowed:
+            event.stop()
             return Forbidden(request, response)
 
 
@@ -28,6 +28,7 @@ class Root(Controller):
     def index(self):
         return "Hello World!"
 
+
 app = Server(("0.0.0.0", 8000))
 ACL().register(app)
 Root().register(app)
