@@ -1,10 +1,9 @@
 #!/usr/bin/env python
-
 from hashlib import md5
 
-from circuits import handler, Component
-from circuits.web import Server, Controller
-from circuits.web.tools import check_auth, basic_auth
+from circuits import Component, handler
+from circuits.web import Controller, Server
+from circuits.web.tools import basic_auth, check_auth
 
 
 class Auth(Component):
@@ -12,8 +11,8 @@ class Auth(Component):
     realm = "Test"
     users = {"admin": md5("admin").hexdigest()}
 
-    @handler("request", filter=True, priority=1.0)
-    def on_request(self, request, response):
+    @handler("request", priority=1.0)
+    def on_request(self, event, request, response):
         """Filter Requests applying Basic Authentication
 
         Filter any incoming requests at a higher priority than the
@@ -22,6 +21,7 @@ class Auth(Component):
         """
 
         if not check_auth(request, response, self.realm, self.users):
+            event.stop()
             return basic_auth(request, response, self.realm, self.users)
 
 
@@ -30,6 +30,7 @@ class Root(Controller):
     def index(self):
         return "Hello World!"
 
+
 app = Server(("0.0.0.0", 8000))
 Auth().register(app)
 Root().register(app)
