@@ -1,6 +1,10 @@
 #!/usr/bin/env python
+"""File Upload
+
+A simple example showing how to access an uploaded file.
+"""
+from circuits.web import Controller, Server
 
-from circuits.web import Server, Controller
 
 UPLOAD_FORM = """
 <html>
@@ -41,9 +45,22 @@ UPLOADED_FILE = """
 class Root(Controller):
 
     def index(self, file=None, desc=""):
+        """Request Handler
+
+        If we haven't received an uploaded file yet, repond with
+        the UPLOAD_FORM template. Otherwise respond with the
+        UPLOADED_FILE template. The file is accessed through
+        the ``file`` keyword argument and the description via
+        the ``desc`` keyword argument. These also happen to be
+        the same fields used on the form.
+        """
+
         if file is None:
             return UPLOAD_FORM
         else:
             return UPLOADED_FILE % (file.filename, desc, file.value)
 
-(Server(8000) + Root()).run()
+
+app = Server(("0.0.0.0", 8000))
+Root().register(app)
+app.run()
