@@ -1,7 +1,6 @@
 #!/usr/bin/env python
-
-from circuits.web import Server, Controller
-from circuits.web.tools import check_auth, basic_auth
+from circuits.web import Controller, Server
+from circuits.web.tools import basic_auth, check_auth
 
 
 class Root(Controller):
@@ -16,4 +15,7 @@ class Root(Controller):
 
         return basic_auth(self.request, self.response, realm, users, encrypt)
 
-(Server(8000) + Root()).run()
+
+app = Server(("0.0.0.0", 8000))
+Root().register(app)
+app.run()
