@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-
-from circuits.web import Server, JSONController
+from circuits.web import JSONController, Server
 
 
 class Root(JSONController):
@@ -8,4 +7,7 @@ class Root(JSONController):
     def index(self):
         return {"success": True, "message": "Hello World!"}
 
-(Server(8000) + Root()).run()
+
+app = Server(("0.0.0.0", 8000))
+Root().register(app)
+app.run()
