@@ -1,11 +1,10 @@
 #!/usr/bin/env python
-
 import os
 
 import mako
 from mako.lookup import TemplateLookup
 
-from circuits.web import Server, Controller, Static
+from circuits.web import Controller, Server, Static
 
 DEFAULTS = {}
 
@@ -21,7 +20,7 @@ def render(name, **d):
         d.update(DEFAULTS)
         tpl = templates.get_template(name)
         return tpl.render(**d)
-    except:
+    except Exception:
         return mako.exceptions.html_error_template().render()
 
 
@@ -36,4 +35,8 @@ class Root(Controller):
         msg = "Thank you %s %s" % (firstName, lastName)
         return render(self.tpl, message=msg)
 
-(Server(8000) + Static() + Root()).run()
+
+app = Server(("0.0.0.0", 8000))
+Static().register(app)
+Root().register(app)
+app.run()
