@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-
-from circuits.web import Server, Controller, Sessions
+from circuits.web import Controller, Server, Sessions
 
 
 class Root(Controller):
@@ -11,4 +10,8 @@ class Root(Controller):
         self.session["name"] = name
         return "Hello %s!" % name
 
-(Server(8000) + Sessions() + Root()).run()
+
+app = Server(("0.0.0.0", 8000))
+Sessions().register(app)
+Root().register(app)
+app.run()
