@@ -1,8 +1,8 @@
 #!/usr/bin/env python
-
 import webbrowser
 
-from circuits.web import Server, Controller
+from circuits.web import Controller, Server
+
 
 HTML = """\
 <html>
@@ -27,8 +27,10 @@ class Root(Controller):
     def exit(self):
         raise SystemExit(0)
 
-server = (Server(8000) + Root())
-server.start()
+
+app = Server(("0.0.0.0", 8000))
+Root().register(app)
+app.start()
 
 webbrowser.open("http://127.0.0.1:8000/")
-server.join()
+app.join()
