@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-
-from circuits.web import Server, Controller
+from circuits.web import Controller, Server
 from circuits.web.dispatchers import VirtualHosts
 
 
@@ -25,9 +24,16 @@ class Bar(Controller):
     def index(self):
         return "I am bar."
 
+
 domains = {
     "foo.localdomain:8000": "foo",
     "bar.localdomain:8000": "bar",
 }
 
-(Server(8000) + VirtualHosts(domains) + Root() + Foo() + Bar()).run()
+
+app = Server(("0.0.0.0", 8000))
+VirtualHosts(domains).register(app)
+Root().register(app)
+Foo().register(app)
+Bar().register(app)
+app.run()
