@@ -1,9 +1,8 @@
 #!/usr/bin/env python
-
-from circuits.net.events import write
 from circuits import Component, Debugger
-from circuits.web.dispatchers import WebSockets
+from circuits.net.events import write
 from circuits.web import Controller, Logger, Server, Static
+from circuits.web.dispatchers import WebSocketsDispatcher
 
 
 class Echo(Component):
@@ -19,11 +18,12 @@ class Root(Controller):
     def index(self):
         return "Hello World!"
 
+
 app = Server(("0.0.0.0", 8000))
 Debugger().register(app)
 Static().register(app)
 Echo().register(app)
 Root().register(app)
 Logger().register(app)
-WebSockets("/websocket").register(app)
+WebSocketsDispatcher("/websocket").register(app)
 app.run()
