@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-
 from circuits.web import Controller
 from circuits.web.wsgi import Application
 
@@ -9,4 +8,6 @@ class Root(Controller):
     def index(self):
         return "Hello World!"
 
-application = Application() + Root()
+
+application = Application()
+Root().register(application)
