@@ -1,16 +1,16 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """wget Example
 
 A basic wget-like clone that asynchronously connections
 a remote web server requesting a given resource.
 """
+from __future__ import print_function
 
 import sys
 
 from circuits import Component
-from circuits.web.client import Client, Request
+from circuits.web.client import Client, request
 
 
 class WebClient(Component):
@@ -21,7 +21,7 @@ class WebClient(Component):
         Client().register(self)
 
     def ready(self, *args):
-        self.fire(Request("GET", self.url))
+        self.fire(request("GET", self.url))
 
     def response(self, response):
         print("{0:d} {1:s}".format(response.status, response.reason))
@@ -34,4 +34,5 @@ class WebClient(Component):
         print(response.read())
         raise SystemExit(0)
 
+
 WebClient(sys.argv[1]).run()
