@@ -1,7 +1,9 @@
 #!/usr/bin/env python
-
-import os
 import sys
+from os.path import abspath
+
+from circuits import Component
+from circuits.app import Daemon
 
 try:
     from coverage import coverage
@@ -9,16 +11,14 @@ try:
 except ImportError:
     HAS_COVERAGE = False
 
-from circuits import Component
-from circuits.app import Daemon
-
 
 class App(Component):
 
-    def __init__(self, pidfile):
-        super(App, self).__init__()
+    def init(self, pidfile):
+        self.pidfile = pidfile
 
-        Daemon(pidfile).register(self)
+    def started(self, *args):
+        Daemon(self.pidfile).register(self)
 
     def prepare_unregister(self, *args):
         return
@@ -29,13 +29,19 @@ def main():
         _coverage = coverage(data_suffix=True)
         _coverage.start()
 
-    pidfile = os.path.abspath(sys.argv[1])
-    app = App(pidfile)
-    app.run()
+    args = iter(sys.argv)
+    next(args)  # executable
+
+    pidfile = next(args)  # pidfile
+
+    pidfile = abspath(pidfile)
+
+    App(pidfile).run()
 
     if HAS_COVERAGE:
         _coverage.stop()
         _coverage.save()
 
+
 if __name__ == "__main__":
     main()
