@@ -1,23 +1,20 @@
 #!/usr/bin/env python
-
 import os
 import sys
 
+from circuits import Component
+from circuits.app import Daemon
+
 try:
     from coverage import coverage
     HAS_COVERAGE = True
 except ImportError:
     HAS_COVERAGE = False
 
-from circuits import Component
-from circuits.app import Daemon
-
 
 class App(Component):
 
-    def __init__(self, pidfile, signalfile):
-        super(App, self).__init__()
-
+    def init(self, pidfile, signalfile):
         self.pidfile = pidfile
         self.signalfile = signalfile
 
@@ -27,6 +24,7 @@ class App(Component):
         f = open(self.signalfile, "w")
         f.write(str(signal))
         f.close()
+        self.stop()
 
 
 def main():
@@ -42,5 +40,6 @@ def main():
         _coverage.stop()
         _coverage.save()
 
+
 if __name__ == "__main__":
     main()
