@@ -1,15 +1,13 @@
 #!/usr/bin/python -i
-
-
-import pytest
-if pytest.PLATFORM == "win32":
-    pytest.skip("Unsupported Platform")
-
-pytest.importorskip("multiprocessing")
-
 from os import getpid
 
-from circuits import Component, Event
+import pytest
+
+from circuits import Component, Event, ipc
+
+pytestmark = pytest.mark.skipif(pytest.PLATFORM == 'win32', reason='Unsupported Platform')
+
+pytest.importorskip("multiprocessing")
 
 
 class hello(Event):
@@ -27,7 +25,7 @@ def test(manager, watcher):
     process, bridge = app.start(process=True, link=manager)
     assert watcher.wait("ready")
 
-    x = manager.fire(hello())
+    x = manager.fire(ipc(hello()))
 
     assert pytest.wait_for(x, "result")
 
