@@ -1,15 +1,16 @@
 #!/usr/bin/python -i
-
-from circuits import Event, Component, Manager
+from circuits import Component, Event, Manager
 
 
 class foo(Event):
+
     """foo Event"""
 
     channels = ("a",)
 
 
 class bar(Event):
+
     """bar Event"""
 
 
@@ -43,7 +44,7 @@ class C(Component):
 def test():
     m = Manager() + A() + B() + C()
 
-    while m:
+    while len(m):
         m.flush()
 
     # Rely on Event.channels
