@@ -1,14 +1,15 @@
 #!/usr/bin/python
-
-from circuits import Event, Component
+from circuits import Component, Event
 
 
-class SimpleEvent(Event):
+class simple_event(Event):
     complete = True
 
 
-class Test(Event):
-    """Test Event"""
+class test(Event):
+
+    """test Event"""
+
     success = True
 
 
@@ -30,8 +31,8 @@ class Nested2(Component):
         """ Updating state. """
         self.root._state = "New state"
         # State change involves even more components as well.
-        self.fire(Test(), Nested3.channel)
-        self.fire(Test(), Nested3.channel)
+        self.fire(test(), Nested3.channel)
+        self.fire(test(), Nested3.channel)
 
 
 class Nested1(Component):
@@ -39,7 +40,7 @@ class Nested1(Component):
 
     def test(self):
         """ State change involves other components as well. """
-        self.fire(Test(), Nested2.channel)
+        self.fire(test(), Nested2.channel)
 
 
 class App(Component):
@@ -54,7 +55,7 @@ class App(Component):
 
     def test(self):
         """ Fire the test event that should produce a state change. """
-        evt = Test()
+        evt = test()
         evt.complete = True
         evt.complete_channels = [self.channel]
         self.fire(evt, Nested1.channel)
@@ -69,12 +70,13 @@ class App(Component):
         """
         self._state_when_complete = self._state
 
+
 app = App()
 Nested1().register(app)
 Nested2().register(app)
 Nested3().register(app)
 
-while app:
+while len(app):
     app.flush()
 
 
@@ -82,16 +84,16 @@ def test_complete_simple():
     """
     Test if complete works for an event without further effects
     """
-    app.fire(SimpleEvent())
-    while app:
+    app.fire(simple_event())
+    while len(app):
         app.flush()
 
     assert app._simple_event_completed
 
 
 def test_complete_nested():
-    app.fire(Test())
-    while app:
+    app.fire(test())
+    while len(app):
         app.flush()
 
     assert app._state_when_success == "Old state"
