@@ -1,21 +1,16 @@
-# Module:   test_component_repr
-# Date:     23rd February 2010
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Component Repr Tests
 
 Test Component's representation string.
 """
-
 import os
 
+from circuits import Component, Event
+
 try:
     from threading import current_thread
 except ImportError:
     from threading import currentThread as current_thread  # NOQA
 
-from circuits import Event, Component
-
 
 class App(Component):
 
@@ -23,17 +18,17 @@ class App(Component):
         pass
 
 
-class Test(Event):
+class test(Event):
     pass
 
 
-def test():
+def test_main():
     id = "%s:%s" % (os.getpid(), current_thread().getName())
     app = App()
 
     assert repr(app) == "<App/* %s (queued=0) [S]>" % id
 
-    app.fire(Test())
+    app.fire(test())
     assert repr(app) == "<App/* %s (queued=1) [S]>" % id
 
     app.flush()
@@ -46,7 +41,7 @@ def test_non_str_channel():
 
     assert repr(app) == "<App/(1, 1) %s (queued=0) [S]>" % id
 
-    app.fire(Test())
+    app.fire(test())
     assert repr(app) == "<App/(1, 1) %s (queued=1) [S]>" % id
 
     app.flush()
