@@ -1,16 +1,13 @@
-# Module:   test_component_setup
-# Date:     23rd February 2010
-# Author:   James Mills, prologic at shortcircuit dot net dot au
+from circuits import Component, Manager
 from circuits.core.handlers import handler
 
+
 """Component Setup Tests
 
-Tests that filters and listeners of a Component are
+Tests that event handlers of a Component are
 automatically registered as event handlers.
 """
 
-from circuits import Component, Manager
-
 
 class App(Component):
 
@@ -51,7 +48,7 @@ def test_basic():
     assert app.test in app._handlers.get("test", set())
 
     app.unregister()
-    while m:
+    while len(m):
         m.flush()
 
     assert not m._handlers
@@ -74,7 +71,7 @@ def test_complex():
     assert b.parent == a
 
     a.unregister()
-    while m:
+    while len(m):
         m.flush()
 
     assert b.informed
