@@ -1,10 +1,10 @@
 #!/usr/bin/python -i
-
-from circuits import Event, Component, Manager
+from circuits import Component, Event, Manager
 
 
-class Test(Event):
-    """Test Event"""
+class test(Event):
+
+    """test Event"""
 
 
 class App(Component):
@@ -12,20 +12,27 @@ class App(Component):
     def test(self):
         return "Hello World!"
 
+    def unregistered(self, *args):
+        return
+
+    def prepare_unregister(self, *args):
+        return
+
+
 m = Manager()
 app = App()
 app.register(m)
 
-while app:
+while len(app):
     app.flush()
 
 
 def test_fire():
-    x = m.fire(Test())
+    x = m.fire(test())
     m.flush()
     assert x.value == "Hello World!"
 
 
 def test_contains():
     assert App in m
-    assert not m in app
+    assert m not in app
