@@ -1,21 +1,17 @@
-# Module:   debugger
-# Date:     5th November 2008
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Debugger Tests"""
 
 import sys
 
 import pytest
 
+from circuits import Debugger
+from circuits.core import Component, Event
+
 try:
     from StringIO import StringIO
 except ImportError:
     from io import StringIO  # NOQA
 
-from circuits import Debugger
-from circuits.core import Event, Component
-
 
 class test(Event):
     """test Event"""
@@ -23,8 +19,6 @@ class test(Event):
 
 class App(Component):
 
-    raiseException = False
-
     def test(self, raiseException=False):
         if raiseException:
             raise Exception()
@@ -32,12 +26,14 @@ class App(Component):
 
 class Logger(object):
 
-    msg = None
+    error_msg = None
+    debug_msg = None
+
+    def error(self, msg):
+        self.error_msg = msg
 
     def debug(self, msg):
-        self.msg = msg
-
-    error = debug
+        self.debug_msg = msg
 
 
 def test_main():
@@ -45,12 +41,12 @@ def test_main():
     stderr = StringIO()
     debugger = Debugger(file=stderr)
     debugger.register(app)
-    while app:
+    while len(app):
         app.flush()
     stderr.seek(0)
     stderr.truncate()
 
-    assert debugger.events
+    assert debugger._events
 
     e = Event()
     app.fire(e)
@@ -61,8 +57,8 @@ def test_main():
     stderr.seek(0)
     stderr.truncate()
 
-    debugger.events = False
-    assert not debugger.events
+    debugger._events = False
+    assert not debugger._events
 
     e = Event()
     app.fire(e)
@@ -81,12 +77,12 @@ def test_file(tmpdir):
     app = App()
     debugger = Debugger(file=stderr)
     debugger.register(app)
-    while app:
+    while len(app):
         app.flush()
     stderr.seek(0)
     stderr.truncate()
 
-    assert debugger.events
+    assert debugger._events
 
     e = Event()
     app.fire(e)
@@ -98,8 +94,8 @@ def test_file(tmpdir):
     stderr.seek(0)
     stderr.truncate()
 
-    debugger.events = False
-    assert not debugger.events
+    debugger._events = False
+    assert not debugger._events
 
     e = Event()
     app.fire(e)
@@ -121,12 +117,12 @@ def test_filename(tmpdir):
     app = App()
     debugger = Debugger(file=logfile)
     debugger.register(app)
-    while app:
+    while len(app):
         app.flush()
     stderr.seek(0)
     stderr.truncate()
 
-    assert debugger.events
+    assert debugger._events
 
     e = Event()
     app.fire(e)
@@ -138,8 +134,8 @@ def test_filename(tmpdir):
     stderr.seek(0)
     stderr.truncate()
 
-    debugger.events = False
-    assert not debugger.events
+    debugger._events = False
+    assert not debugger._events
 
     e = Event()
     app.fire(e)
@@ -156,13 +152,13 @@ def test_exceptions():
     stderr = StringIO()
     debugger = Debugger(file=stderr)
     debugger.register(app)
-    while app:
+    while len(app):
         app.flush()
     stderr.seek(0)
     stderr.truncate()
 
-    assert debugger.events
-    assert debugger.errors
+    assert debugger._events
+    assert debugger._errors
 
     e = test(raiseException=True)
     app.fire(e)
@@ -177,15 +173,15 @@ def test_exceptions():
     app.flush()
     stderr.seek(0)
     s = stderr.read().strip()
-    assert s.startswith("<error[*]")
+    assert s.startswith("<exception[*]")
     stderr.seek(0)
     stderr.truncate()
 
-    debugger.events = False
-    debugger.errors = False
+    debugger._events = False
+    debugger._errors = False
 
-    assert not debugger.events
-    assert not debugger.errors
+    assert not debugger._events
+    assert not debugger._errors
 
     e = test(raiseException=True)
     app.fire(e)
@@ -208,12 +204,12 @@ def test_IgnoreEvents():
     stderr = StringIO()
     debugger = Debugger(file=stderr)
     debugger.register(app)
-    while app:
+    while len(app):
         app.flush()
     stderr.seek(0)
     stderr.truncate()
 
-    assert debugger.events
+    assert debugger._events
 
     debugger.IgnoreEvents.extend(["test"])
 
@@ -243,12 +239,12 @@ def test_IgnoreChannels():
     stderr = StringIO()
     debugger = Debugger(file=stderr)
     debugger.register(app)
-    while app:
+    while len(app):
         app.flush()
     stderr.seek(0)
     stderr.truncate()
 
-    assert debugger.events
+    assert debugger._events
     debugger.IgnoreChannels.extend([("*", "test")])
 
     e = Event()
@@ -277,14 +273,14 @@ def test_Logger_debug():
     logger = Logger()
     debugger = Debugger(logger=logger)
     debugger.register(app)
-    while app:
+    while len(app):
         app.flush()
 
     e = Event()
     app.fire(e)
     app.flush()
 
-    assert logger.msg == repr(e)
+    assert logger.debug_msg == repr(e)
 
 
 def test_Logger_error():
@@ -292,11 +288,12 @@ def test_Logger_error():
     logger = Logger()
     debugger = Debugger(logger=logger)
     debugger.register(app)
-    while app:
+    while len(app):
         app.flush()
 
     e = test(raiseException=True)
     app.fire(e)
-    app.flush()
-    app.flush()
-    assert logger.msg.startswith("ERROR <handler[*.test] (App.test)> (")
+    while len(app):
+        app.flush()
+
+    assert logger.error_msg.startswith("ERROR <handler[*][test] (App.test)> (")
