@@ -1,16 +1,13 @@
-# Module:   test_event
-# Date:     12th April 2010
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Event Tests"""
 
 import py
 
-from circuits import Event, Component
+from circuits import Component, Event
 
 
-class Test(Event):
-    """Test Event"""
+class test(Event):
+
+    """test Event"""
 
 
 class App(Component):
@@ -21,42 +18,42 @@ class App(Component):
 
 def test_repr():
     app = App()
-    while app:
+    while len(app):
         app.flush()
 
-    e = Test()
+    e = test()
 
     s = repr(e)
-    assert s == "<Test[.test] ( )>"
+    assert s == "<test[] ( )>"
 
     app.fire(e)
 
     s = repr(e)
-    assert s == "<Test[*.test] ( )>"
+    assert s == "<test[*] ( )>"
 
 
 def test_create():
     app = App()
-    while app:
+    while len(app):
         app.flush()
 
-    e = Event.create("Test")
+    e = Event.create("test")
 
     s = repr(e)
-    assert s == "<Test[.test] ( )>"
+    assert s == "<test[] ( )>"
 
     app.fire(e)
 
     s = repr(e)
-    assert s == "<Test[*.test] ( )>"
+    assert s == "<test[*] ( )>"
 
 
 def test_getitem():
     app = App()
-    while app:
+    while len(app):
         app.flush()
 
-    e = Test(1, 2, 3, foo="bar")
+    e = test(1, 2, 3, foo="bar")
 
     assert e[0] == 1
     assert e["foo"] == "bar"
@@ -69,10 +66,10 @@ def test_getitem():
 
 def test_setitem():
     app = App()
-    while app:
+    while len(app):
         app.flush()
 
-    e = Test(1, 2, 3, foo="bar")
+    e = test(1, 2, 3, foo="bar")
 
     assert e[0] == 1
     assert e["foo"] == "bar"
@@ -87,3 +84,10 @@ def test_setitem():
 
     assert e[0] == 0
     assert e["foo"] == "Hello"
+
+
+def test_subclass_looses_properties():
+    class hello(Event):
+        success = True
+    e = hello().child('success')
+    assert e.success is False
