@@ -2,8 +2,6 @@
 import sys
 from subprocess import PIPE, Popen
 
-from circuits.six import b
-
 from . import exitcodeapp
 
 
@@ -23,4 +21,4 @@ def test_string(tmpdir):
     status = p.wait()
 
     assert status == 1
-    assert p.stderr.read() == b("foobar\n")
+    assert p.stderr.read() == b"foobar\n"
