@@ -1,16 +1,13 @@
-# Module:   test_feedback
-# Date:     11th February 2010
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Feedback Channels Tests"""
 
 import py
 
-from circuits import handler, Event, Component
+from circuits import Component, Event, handler
 
 
-class Test(Event):
-    """Test Event"""
+class test(Event):
+
+    """test Event"""
 
     success = True
     failure = True
@@ -27,10 +24,10 @@ class App(Component):
         self.success = False
         self.failure = False
 
-    @handler("*", filter=True)
+    @handler("*")
     def event(self, event, *args, **kwargs):
         if kwargs.get("filter", False):
-            return True
+            event.stop()
 
     def test(self, error=False):
         if error:
@@ -55,20 +52,20 @@ def reraise(e):
 
 def test_success():
     app = App()
-    while app:
+    while len(app):
         app.flush()
 
-    e = Test()
+    e = test()
     value = app.fire(e)
 
-    while app:
+    while len(app):
         app.flush()
 
     # The Event
     s = value.value
     assert s == "Hello World!"
 
-    while app:
+    while len(app):
         app.flush()
 
     assert app.e == e
@@ -79,19 +76,19 @@ def test_success():
 
 def test_failure():
     app = App()
-    while app:
+    while len(app):
         app.flush()
 
-    e = Test(error=True)
+    e = test(error=True)
     x = app.fire(e)
 
-    while app:
+    while len(app):
         app.flush()
 
     # The Event
     py.test.raises(Exception, lambda x: reraise(x[1]), x.value)
 
-    while app:
+    while len(app):
         app.flush()
 
     assert app.e == e
