@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-
 import pytest
 
 from circuits import Component, Event
@@ -14,16 +13,16 @@ class App(Component):
 
     def registered(self, component, manager):
         if component is self:
-            self.fire(Event.create("Ready"))
+            self.fire(Event.create("ready"))
 
     def generate_events(self, event):
         if not self._ready or self._done:
             return
 
         if self._counter < 10:
-            self.fire(Event.create("Hello"))
+            self.fire(Event.create("hello"))
         else:
-            self.fire(Event.create("Done"))
+            self.fire(Event.create("done"))
         event.reduce_time_left(0)
 
     def done(self):
@@ -36,7 +35,7 @@ class App(Component):
         self._ready = True
 
 
-@pytest.fixture(scope="module")
+@pytest.fixture
 def app(request, manager, watcher):
     app = App().register(manager)
 
