@@ -1,14 +1,15 @@
 #!/usr/bin/env python
-
-from circuits import Event, Component
+from circuits import Component, Event
 
 
-class Test(Event):
-    """Test Event"""
+class test(Event):
+
+    """test Event"""
 
 
-class Hello(Event):
-    """Hello Event"""
+class hello(Event):
+
+    """hello Event"""
 
 
 class App(Component):
@@ -26,10 +27,10 @@ class App(Component):
 
 def test_return_generator():
     app = App()
-    while app:
+    while len(app):
         app.flush()
 
-    v = app.fire(Test())
+    v = app.fire(test())
     app.tick()
     app.tick()
 
@@ -39,10 +40,10 @@ def test_return_generator():
 
 def test_yield():
     app = App()
-    while app:
+    while len(app):
         app.flush()
 
-    v = app.fire(Hello())
+    v = app.fire(hello())
     app.tick()
     app.tick()
     app.tick()
