@@ -1,14 +1,15 @@
 #!/usr/bin/env python
-
-from circuits import handler, Event, Component
+from circuits import Component, Event, handler
 
 
-class Foo(Event):
-    """Foo Event"""
+class foo(Event):
+
+    """foo Event"""
 
 
-class Test(Event):
-    """Test Event"""
+class test(Event):
+
+    """test Event"""
 
 
 class A(Component):
@@ -30,13 +31,13 @@ class B(Component):
         return "Bar"
 
 
-def test():
+def test_main():
     app = A() + B()
-    while app:
+    while len(app):
         app.flush()
 
-    x = app.fire(Test(), "a")
-    while app:
+    x = app.fire(test(), "a")
+    while len(app):
         app.flush()
 
     assert x.value[0] == "Bar"
@@ -46,12 +47,12 @@ def test():
 
 def test_event():
     app = A() + B()
-    while app:
+    while len(app):
         app.flush()
 
-    e = Test()
+    e = test()
     x = app.fire(e)
-    while app:
+    while len(app):
         app.flush()
 
     assert x.value[0] == "Bar"
@@ -61,12 +62,12 @@ def test_event():
 
 def test_channel():
     app = A() + B()
-    while app:
+    while len(app):
         app.flush()
 
-    e = Foo()
+    e = foo()
     x = app.fire(e, "b")
-    while app:
+    while len(app):
         app.flush()
 
     assert x.value == "Bar"
