@@ -1,19 +1,14 @@
-# Module:   test_manager_repr
-# Date:     23rd February 2010
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Manager Repr Tests
 
 Test Manager's representation string.
 """
-
 import os
-from time import sleep
 from threading import current_thread
+from time import sleep
 
 import pytest
 
-from circuits import Event, Component, Manager
+from circuits import Component, Manager
 
 
 class App(Component):
@@ -22,11 +17,7 @@ class App(Component):
         pass
 
 
-class Test(Event):
-    pass
-
-
-def test():
+def test_main():
     id = "%s:%s" % (os.getpid(), current_thread().getName())
 
     m = Manager()
