@@ -1,10 +1,10 @@
 #!/usr/bin/python -i
-
-from circuits import handler, Event, Component, Manager
+from circuits import Component, Event, Manager, handler
 
 
-class Test(Event):
-    """Test Event"""
+class test(Event):
+
+    """test Event"""
 
 
 class App(Component):
@@ -21,17 +21,18 @@ class App(Component):
     def test_2(self):
         return 2
 
+
 m = Manager()
 app = App()
 app.register(m)
 
-while m:
+while len(m):
     m.flush()
 
 
-def test():
-    v = m.fire(Test())
-    while m:
+def test_main():
+    v = m.fire(test())
+    while len(m):
         m.flush()
     x = list(v)
     assert x == [3, 2, 0]
