@@ -1,21 +1,36 @@
 #!/usr/bin/env python
+import os
+import sys
+from errno import ESRCH
+from os import kill, remove
+from signal import SIGTERM
+from subprocess import Popen
+from time import sleep
 
 import pytest
 
-import os
-import sys
+from . import signalapp
+
+
+def is_running(pid):
+    try:
+        kill(pid, 0)
+    except OSError as error:
+        if error.errno == ESRCH:
+            return False
+    return True
+
+
+def wait(pid, timeout=3):
+    count = timeout
+    while is_running(pid) and count:
+        sleep(1)
 
 
 def test(tmpdir):
     if not os.name == "posix":
         pytest.skip("Cannot run test on a non-POSIX platform.")
 
-    from time import sleep
-    from subprocess import Popen
-    from signal import SIGTERM
-
-    from tests.core import signalapp
-
     tmpdir.ensure(".pid")
     tmpdir.ensure(".signal")
     pidfile = str(tmpdir.join(".pid"))
@@ -37,14 +52,13 @@ def test(tmpdir):
     pid = int(f.read().strip())
     f.close()
 
-    os.kill(pid, SIGTERM)
-    sleep(1)
+    kill(pid, SIGTERM)
+    wait(pid)
 
-    f = open(signalfile, "r")
-    signal = f.read().strip()
-    f.close()
+    with open(signalfile, "r") as fd:
+        signal = fd.read().strip()
 
-    assert signal == str(SIGTERM)
+    assert int(signal) == int(SIGTERM)
 
-    os.remove(pidfile)
-    os.remove(signalfile)
+    remove(pidfile)
+    remove(signalfile)
