@@ -1,11 +1,11 @@
 #!/usr/bin/env python
-
 import sys
 from types import ModuleType
 
 from circuits import Component
 from circuits.core.utils import findchannel, findroot, findtype
 
+
 FOO = """\
 def foo():
     return "Hello World!"
@@ -18,6 +18,7 @@ def foo();
 
 
 class Base(Component):
+
     """Base"""
 
 
@@ -64,14 +65,6 @@ def test_safeimport(tmpdir):
     assert foo not in sys.modules
 
 
-def test_uncamel():
-    from circuits.core.utils import uncamel
-
-    s = "FooBar"
-    x = uncamel(s)
-    assert x == "foo_bar"
-
-
 def test_findroot():
     app = App()
     a = A()
@@ -80,7 +73,7 @@ def test_findroot():
     b.register(a)
     a.register(app)
 
-    while app:
+    while len(app):
         app.flush()
 
     root = findroot(b)
@@ -92,7 +85,7 @@ def test_findchannel():
     app = App()
     (A() + B()).register(app)
 
-    while app:
+    while len(app):
         app.flush()
 
     a = findchannel(app, "a")
@@ -104,7 +97,7 @@ def test_findtype():
     app = App()
     (A() + B()).register(app)
 
-    while app:
+    while len(app):
         app.flush()
 
     a = findtype(app, A)
