@@ -1,23 +1,28 @@
 #!/usr/bin/python -i
+from types import TracebackType
 
 import pytest
 
-from circuits import handler, Event, Component
+from circuits import Component, Event, handler
 
 
 class hello(Event):
-    "Hhllo Event"
+
+    "Hello Event"
 
 
 class test(Event):
+
     "test Event"
 
 
 class foo(Event):
+
     "foo Event"
 
 
 class values(Event):
+
     "values Event"
 
     complete = True
@@ -56,70 +61,63 @@ class App(Component):
 
 
 @pytest.fixture
-def app(request, manager, watcher):
-    app = App().register(manager)
-    watcher.wait("registered")
-
-    def finalizer():
-        app.unregister()
-        watcher.wait("unregistered")
-
-    request.addfinalizer(finalizer)
-
-    return app
+def app(request, simple_manager):
+    return App().register(simple_manager)
 
 
-def test_value(app, watcher):
+def test_value(app, simple_manager):
     x = app.fire(hello())
-    watcher.wait("hello")
+    simple_manager.run()
 
     assert "Hello World!" in x
     assert x.value == "Hello World!"
 
 
-def test_nested_value(app, watcher):
+def test_nested_value(app, simple_manager):
     x = app.fire(test())
-    watcher.wait("test")
+    simple_manager.run()
 
     assert x.value == "Hello World!"
     assert str(x) == "Hello World!"
 
 
-def test_value_notify(app, watcher):
-    x = app.fire(hello())
-    x.notify = True
+def test_value_notify(app, simple_manager):
+    ev = hello()
+    ev.notify = True
+    x = app.fire(ev)
 
-    watcher.wait("hello_value_changed")
+    simple_manager.run()
 
     assert "Hello World!" in x
     assert x.value == "Hello World!"
     assert app.value is x
 
 
-def test_nested_value_notify(app, watcher):
-    x = app.fire(test())
-    x.notify = True
+def test_nested_value_notify(app, simple_manager):
+    ev = test()
+    ev.notify = True
+    x = app.fire(ev)
 
-    watcher.wait("hello_value_changed")
+    simple_manager.run()
 
     assert x.value == "Hello World!"
     assert str(x) == "Hello World!"
     assert app.value is x
 
 
-def test_error_value(app, watcher):
+def test_error_value(app, simple_manager):
     x = app.fire(foo())
-    watcher.wait("foo")
+    simple_manager.run()
 
     etype, evalue, etraceback = x
     assert etype is Exception
     assert str(evalue) == "ERROR"
-    assert isinstance(etraceback, list)
+    assert isinstance(etraceback, TracebackType)
 
 
-def test_multiple_values(app, watcher):
+def test_multiple_values(app, simple_manager):
     v = app.fire(values())
-    watcher.wait("values_complete")
+    simple_manager.run()
 
     assert isinstance(v.value, list)
 
