@@ -1,17 +1,13 @@
-# Module:   test_workers
-# Date:     7th October 2008
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Workers Tests"""
 
-import pytest
-
 from os import getpid
 
-from circuits import Task, Worker
+import pytest
+
+from circuits import Worker, task
 
 
-@pytest.fixture(scope="module")
+@pytest.fixture
 def worker(request, manager):
     worker = Worker().register(manager)
 
@@ -40,8 +36,12 @@ def pid():
     return "Hello from {0:d}".format(getpid())
 
 
+def add(a, b):
+    return a + b
+
+
 def test_failure(manager, watcher, worker):
-    e = Task(err)
+    e = task(err)
     e.failure = True
 
     x = worker.fire(e)
@@ -52,7 +52,7 @@ def test_failure(manager, watcher, worker):
 
 
 def test_success(manager, watcher, worker):
-    e = Task(foo)
+    e = task(foo)
     e.success = True
 
     x = worker.fire(e)
@@ -60,3 +60,14 @@ def test_success(manager, watcher, worker):
     assert watcher.wait("task_success")
 
     assert x.value == 1000000
+
+
+def test_args(manager, watcher, worker):
+    e = task(add, 1, 2)
+    e.success = True
+
+    x = worker.fire(e)
+
+    assert watcher.wait("task_success")
+
+    assert x.value == 3
