@@ -1,16 +1,76 @@
 #!/usr/bin/env python
+import os.path
+import select
+from socket import (
+    AF_INET, AF_INET6, EAI_NODATA, EAI_NONAME, SOCK_STREAM,
+    error as SocketError, has_ipv6, socket,
+)
+from ssl import wrap_socket as sslsocket
 
-from socket import socket, AF_INET, AF_INET6, SOCK_STREAM, has_ipv6
 import pytest
+from tests.conftest import WaitEvent
 
-from circuits import Manager
-from circuits.core.pollers import Select
-from circuits.net.sockets import TCPServer, TCP6Server, TCPClient, TCP6Client
-from circuits.net.sockets import Close, Connect, Write
+from circuits import Debugger, Manager
+from circuits.core.pollers import EPoll, KQueue, Poll, Select
+from circuits.net.events import close, connect, write
+from circuits.net.sockets import TCP6Client, TCP6Server, TCPClient, TCPServer
 
 from .client import Client
 from .server import Server
 
+CERT_FILE = os.path.join(os.path.dirname(__file__), "cert.pem")
+
+
+class TestClient(object):
+
+    def __init__(self, ipv6=False):
+        self._sockname = None
+
+        self.sock = socket(
+            AF_INET6 if ipv6
+            else AF_INET,
+            SOCK_STREAM
+        )
+
+        self.ssock = sslsocket(self.sock)
+
+    @property
+    def sockname(self):
+        return self._sockname
+
+    def connect(self, host, port):
+        self.ssock.connect_ex((host, port))
+        self._sockname = self.ssock.getsockname()
+
+    def send(self, data):
+        self.ssock.send(data)
+
+    def recv(self, buflen=4069):
+        return self.ssock.recv(buflen)
+
+    def disconnect(self):
+        try:
+            self.ssock.shutdown(2)
+        except SocketError:
+            pass
+
+        try:
+            self.ssock.close()
+        except SocketError:
+            pass
+
+
+@pytest.fixture
+def client(request, ipv6):
+    client = TestClient(ipv6=ipv6)
+
+    def finalizer():
+        client.disconnect()
+
+    request.addfinalizer(finalizer)
+
+    return client
+
 
 def wait_host(server):
     def checker(obj, attr):
@@ -18,40 +78,28 @@ def wait_host(server):
     assert pytest.wait_for(server, ("host", "port"), checker)
 
 
-def _pytest_generate_tests(metafunc, ipv6):
-    metafunc.addcall(funcargs={"Poller": Select, "ipv6": ipv6})
-
-    try:
-        from circuits.core.pollers import Poll
-        Poll()
-        metafunc.addcall(funcargs={"Poller": Poll, "ipv6": ipv6})
-    except AttributeError:
-        pass
-
-    try:
-        from circuits.core.pollers import EPoll
-        EPoll()
-        metafunc.addcall(funcargs={"Poller": EPoll, "ipv6": ipv6})
-    except AttributeError:
-        pass
-
-    try:
-        from circuits.core.pollers import KQueue
-        KQueue()
-        metafunc.addcall(funcargs={"Poller": KQueue, "ipv6": ipv6})
-    except AttributeError:
-        pass
-
-
 def pytest_generate_tests(metafunc):
-    _pytest_generate_tests(metafunc, ipv6=False)
+    ipv6 = [False]
     if has_ipv6:
-        _pytest_generate_tests(metafunc, ipv6=True)
+        ipv6.append(True)
+
+    for ipv6 in ipv6:
+        poller = [(Select, ipv6)]
+
+        if hasattr(select, "poll"):
+            poller.append((Poll, ipv6))
+
+        if hasattr(select, "epoll"):
+            poller.append((EPoll, ipv6))
+
+        if hasattr(select, "kqueue"):
+            poller.append((KQueue, ipv6))
+
+    metafunc.parametrize('Poller,ipv6', poller)
 
 
 def test_tcp_basic(Poller, ipv6):
-    from circuits import Debugger
-    m = Manager() + Poller() + Debugger()
+    m = Manager() + Poller()
 
     if ipv6:
         tcp_server = TCP6Server(("::1", 0))
@@ -72,31 +120,64 @@ def test_tcp_basic(Poller, ipv6):
         assert pytest.wait_for(server, "ready")
         wait_host(server)
 
-        client.fire(Connect(server.host, server.port))
+        client.fire(connect(server.host, server.port))
         assert pytest.wait_for(client, "connected")
         assert pytest.wait_for(server, "connected")
         assert pytest.wait_for(client, "data", b"Ready")
 
-        client.fire(Write(b"foo"))
+        client.fire(write(b"foo"))
         assert pytest.wait_for(server, "data", b"foo")
         assert pytest.wait_for(client, "data", b"foo")
 
-        client.fire(Close())
+        client.fire(close())
         assert pytest.wait_for(client, "disconnected")
         assert pytest.wait_for(server, "disconnected")
 
-        server.fire(Close())
+        server.fire(close())
         assert pytest.wait_for(server, "closed")
     finally:
         m.stop()
 
 
-def test_tcp_reconnect(Poller, ipv6):
-    ### XXX: Apparently this doesn't work on Windows either?
-    ### XXX: UPDATE: Apparently Broken on Windows + Python 3.2
-    ### TODO: Need to look into this. Find out why...
+def test_tcps_basic(manager, watcher, client, Poller, ipv6):
+    poller = Poller().register(manager)
 
-    if pytest.PLATFORM == "win32" and pytest.PYVER[:2] == (3, 2):
+    if ipv6:
+        tcp_server = TCP6Server(("::1", 0), secure=True, certfile=CERT_FILE)
+    else:
+        tcp_server = TCPServer(0, secure=True, certfile=CERT_FILE)
+
+    server = Server() + tcp_server
+
+    server.register(manager)
+
+    try:
+        watcher.wait("ready", "server")
+
+        client.connect(server.host, server.port)
+        assert watcher.wait("connect", "server")
+        assert client.recv() == b"Ready"
+
+        client.send(b"foo")
+        assert watcher.wait("read", "server")
+        assert client.recv() == b"foo"
+
+        client.disconnect()
+        assert watcher.wait("disconnect", "server")
+
+        server.fire(close())
+        assert watcher.wait("closed", "server")
+    finally:
+        poller.unregister()
+        server.unregister()
+
+
+def test_tcp_reconnect(Poller, ipv6):
+    # XXX: Apparently this doesn't work on Windows either?
+    # XXX: UPDATE: Apparently Broken on Windows + Python 3.2
+    # TODO: Need to look into this. Find out why...
+
+    if pytest.PLATFORM == "win32" and pytest.PYVER[:2] >= (3, 2):
         pytest.skip("Broken on Windows on Python 3.2")
 
     m = Manager() + Poller()
@@ -121,54 +202,50 @@ def test_tcp_reconnect(Poller, ipv6):
         wait_host(server)
 
         # 1st connect
-        client.fire(Connect(server.host, server.port))
+        client.fire(connect(server.host, server.port))
         assert pytest.wait_for(client, "connected")
         assert pytest.wait_for(server, "connected")
         assert pytest.wait_for(client, "data", b"Ready")
 
-        client.fire(Write(b"foo"))
+        client.fire(write(b"foo"))
         assert pytest.wait_for(server, "data", b"foo")
 
         # disconnect
-        client.fire(Close())
+        client.fire(close())
         assert pytest.wait_for(client, "disconnected")
 
         # 2nd reconnect
-        client.fire(Connect(server.host, server.port))
+        client.fire(connect(server.host, server.port))
         assert pytest.wait_for(client, "connected")
         assert pytest.wait_for(server, "connected")
         assert pytest.wait_for(client, "data", b"Ready")
 
-        client.fire(Write(b"foo"))
+        client.fire(write(b"foo"))
         assert pytest.wait_for(server, "data", b"foo")
 
-        client.fire(Close())
+        client.fire(close())
         assert pytest.wait_for(client, "disconnected")
         assert pytest.wait_for(server, "disconnected")
 
-        server.fire(Close())
+        server.fire(close())
         assert pytest.wait_for(server, "closed")
     finally:
         m.stop()
 
 
 def test_tcp_connect_closed_port(Poller, ipv6):
-    ### FIXME: This test is wrong.
-    ### We need to figure out the sequence of events on Windows
-    ### for this scenario. I think if you attempt to connect to
-    ### a shutdown listening socket (tcp server) you should get
-    ### an error event as response.
 
     if pytest.PLATFORM == "win32":
         pytest.skip("Broken on Windows")
 
-    m = Manager() + Poller()
+    m = Manager() + Poller() + Debugger()
+
     if ipv6:
         tcp_server = TCP6Server(("::1", 0))
-        tcp_client = TCP6Client()
+        tcp_client = TCP6Client(connect_timeout=1)
     else:
         tcp_server = TCPServer(0)
-        tcp_client = TCPClient()
+        tcp_client = TCPClient(connect_timeout=1)
     server = Server() + tcp_server
     client = Client() + tcp_client
 
@@ -186,16 +263,12 @@ def test_tcp_connect_closed_port(Poller, ipv6):
         tcp_server._sock.close()
 
         # 1st connect
-        client.fire(Connect(host, port))
-        assert pytest.wait_for(client, "connected")
-
-        client.fire(Write(b"foo"))
-        assert pytest.wait_for(client, "disconnected")
-
-        client.disconnected = False
-        client.fire(Write(b"foo"))
-        assert pytest.wait_for(client, "disconnected", timeout=1.0) is None
+        client.fire(connect(host, port))
+        waiter = WaitEvent(m, "unreachable", channel='client')
+        assert waiter.wait()
     finally:
+        server.unregister()
+        client.unregister()
         m.stop()
 
 
@@ -229,21 +302,47 @@ def test_tcp_bind(Poller, ipv6):
         assert pytest.wait_for(server, "ready")
         wait_host(server)
 
-        client.fire(Connect(server.host, server.port))
+        client.fire(connect(server.host, server.port))
         assert pytest.wait_for(client, "connected")
         assert pytest.wait_for(server, "connected")
         assert pytest.wait_for(client, "data", b"Ready")
 
-        #assert server.client[1] == bind_port
+        # assert server.client[1] == bind_port
 
-        client.fire(Write(b"foo"))
+        client.fire(write(b"foo"))
         assert pytest.wait_for(server, "data", b"foo")
 
-        client.fire(Close())
+        client.fire(close())
         assert pytest.wait_for(client, "disconnected")
         assert pytest.wait_for(server, "disconnected")
 
-        server.fire(Close())
+        server.fire(close())
         assert pytest.wait_for(server, "closed")
     finally:
         m.stop()
+
+
+def test_tcp_lookup_failure(manager, watcher, Poller, ipv6):
+    poller = Poller().register(manager)
+
+    if ipv6:
+        tcp_client = TCP6Client()
+    else:
+        tcp_client = TCPClient()
+
+    client = Client() + tcp_client
+    client.register(manager)
+
+    try:
+        assert watcher.wait("ready", "client")
+
+        client.fire(connect("foo.bar.baz", 1234))
+        assert watcher.wait("error", "client")
+
+        if pytest.PLATFORM == "win32":
+            assert client.error.errno == 11004
+        else:
+            assert client.error.errno in (EAI_NODATA, EAI_NONAME,)
+    finally:
+        poller.unregister()
+        client.unregister()
