@@ -1,15 +1,13 @@
 #!/usr/bin/env python
+import select
+import socket
 
 import pytest
 
-import socket
-import select
-
 from circuits import Manager
-from circuits.core.events import unregister
+from circuits.core.pollers import EPoll, KQueue, Poll, Select
 from circuits.net.events import close, write
-from circuits.core.pollers import Select, Poll, EPoll, KQueue
-from circuits.net.sockets import UDPServer, UDPClient, UDP6Server, UDP6Client
+from circuits.net.sockets import UDP6Client, UDP6Server, UDPClient, UDPServer
 
 from .client import Client
 from .server import Server
@@ -21,23 +19,24 @@ def wait_host(server):
     assert pytest.wait_for(server, ("host", "port"), checker)
 
 
-def _pytest_generate_tests(metafunc, ipv6):
-    metafunc.addcall(funcargs={"Poller": Select, "ipv6": ipv6})
-
-    if hasattr(select, "poll"):
-        metafunc.addcall(funcargs={"Poller": Poll, "ipv6": ipv6})
-
-    if hasattr(select, "epoll"):
-        metafunc.addcall(funcargs={"Poller": EPoll, "ipv6": ipv6})
-
-    if hasattr(select, "kqueue"):
-        metafunc.addcall(funcargs={"Poller": KQueue, "ipv6": ipv6})
-
-
 def pytest_generate_tests(metafunc):
-    _pytest_generate_tests(metafunc, ipv6=False)
+    ipv6 = [False]
     if socket.has_ipv6:
-        _pytest_generate_tests(metafunc, ipv6=True)
+        ipv6.append(True)
+
+    for ipv6 in ipv6:
+        poller = [(Select, ipv6)]
+
+        if hasattr(select, "poll"):
+            poller.append((Poll, ipv6))
+
+        if hasattr(select, "epoll"):
+            poller.append((EPoll, ipv6))
+
+        if hasattr(select, "kqueue"):
+            poller.append((KQueue, ipv6))
+
+    metafunc.parametrize('Poller,ipv6', poller)
 
 
 def test_basic(Poller, ipv6):
@@ -89,7 +88,7 @@ def test_close(Poller, ipv6):
         server.fire(close())
         assert pytest.wait_for(server, "disconnected")
 
-        server.fire(unregister(server))
+        server.unregister()
 
         def test(obj, attr):
             return attr not in obj.components
