@@ -1,22 +1,17 @@
-# Module:   test_tools
-# Date:     13th March 2009
-# Author:   James Mills, prologic at shortcircuit dot net dot au
-
 """Tools Test Suite
 
 Test all functionality of the tools package.
 """
-
 import pytest
 
+from circuits import Component, reprhandler
+from circuits.tools import findroot, inspect, kill, tryimport
+
 try:
     from threading import current_thread
 except ImportError:
     from threading import currentThread as current_thread  # NOQA
 
-from circuits import Component, reprhandler
-from circuits.tools import kill, inspect, findroot, tryimport
-
 
 class A(Component):
 
@@ -53,18 +48,6 @@ class F(Component):
     def foo(self):
         print("F!")
 
-INSPECT = """\
- Components: 0
-
- Event Handlers: 3
-  unregister; 1
-   <listener[*.unregister] (A._on_unregister)>
-  foo; 1
-   <listener[*.foo] (A.foo)>
-  prepare_unregister_complete; 1
-   <listener[<instance of A>.prepare_unregister_complete] (A._on_prepare_unregister_complete)>
-"""
-
 
 def test_kill():
     a = A()
@@ -98,7 +81,7 @@ def test_kill():
     assert not f.components
 
     assert kill(d) is None
-    while a:
+    while len(a):
         a.flush()
 
     assert a.parent == a
@@ -107,9 +90,9 @@ def test_kill():
     assert not c.components
 
     assert b in a.components
-    assert not d in a.components
-    assert not e in d.components
-    assert not f in e.components
+    assert d not in a.components
+    assert e not in d.components
+    assert f not in e.components
 
     assert d.parent == d
     assert e.parent == e
@@ -121,13 +104,15 @@ def test_kill():
 
 
 def test_inspect():
-    if pytest.PYVER[:2] == (3, 3):
-        pytest.skip("Broken on Python 3.3")
-
     a = A()
     s = inspect(a)
 
-    assert s == INSPECT
+    assert "Components: 0" in s
+    assert "Event Handlers: 2" in s
+    assert "foo; 1" in s
+    assert "<handler[*][foo] (A.foo)>" in s
+    assert "prepare_unregister_complete; 1" in s
+    assert "<handler[<instance of A>][prepare_unregister_complete] (A._on_prepare_unregister_complete)>" in s
 
 
 def test_findroot():
@@ -151,10 +136,9 @@ def test_findroot():
 def test_reprhandler():
     a = A()
     s = reprhandler(a.foo)
-    assert s == "<listener[*.foo] (A.foo)>"
+    assert s == "<handler[*][foo] (A.foo)>"
 
-    f = lambda: None
-    pytest.raises(AttributeError, reprhandler, f)
+    pytest.raises(AttributeError, reprhandler, lambda: None)
 
 
 def test_tryimport():
@@ -172,6 +156,3 @@ def test_tryimport_obj():
 def test_tryimport_fail():
     m = tryimport("asdf")
     assert m is None
-
-
-# flake8: noqa
