@@ -1,7 +1,6 @@
-
 import itertools
-from mimetypes import guess_type
 from email.generator import _make_boundary
+from mimetypes import guess_type
 
 
 class MultiPartForm(dict):
@@ -38,7 +37,7 @@ class MultiPartForm(dict):
         parts.extend([
             part_boundary,
             bytearray(
-                "Content-Disposition: file; name=\"%s\"; filename=\"%s\"" % (
+                "Content-Disposition: form-data; name=\"%s\"; filename=\"%s\"" % (
                     fieldname, filename),
                 "ascii"
             ),
