@@ -5,7 +5,6 @@ try:
 except ImportError:
     from http.client import HTTPConnection  # NOQA
 
-from circuits.six import b
 from circuits.web import Controller
 
 
@@ -21,7 +20,7 @@ def test_bad_header(webapp):
 
     connection.putrequest("GET", "/", "HTTP/1.1")
     connection.putheader("Connection", "close")
-    connection._output(b("X-Foo"))  # Bad Header
+    connection._output(b"X-Foo")  # Bad Header
     connection.endheaders()
 
     response = connection.getresponse()
