@@ -1,8 +1,9 @@
 from circuits.web import Controller
-from circuits.web.tools import check_auth, basic_auth
+from circuits.web.tools import basic_auth, check_auth
 
-from .helpers import HTTPError, HTTPBasicAuthHandler
-from .helpers import urlopen, build_opener, install_opener
+from .helpers import (
+    HTTPBasicAuthHandler, HTTPError, build_opener, install_opener, urlopen,
+)
 
 
 class Root(Controller):
@@ -20,7 +21,7 @@ class Root(Controller):
 
 def test(webapp):
     try:
-        f = urlopen(webapp.server.base)
+        f = urlopen(webapp.server.http.base)
     except HTTPError as e:
         assert e.code == 401
         assert e.msg == "Unauthorized"
@@ -28,10 +29,11 @@ def test(webapp):
         assert False
 
     handler = HTTPBasicAuthHandler()
-    handler.add_password("Test", webapp.server.base, "admin", "admin")
+    handler.add_password("Test", webapp.server.http.base, "admin", "admin")
     opener = build_opener(handler)
     install_opener(opener)
 
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
+    install_opener(None)
