@@ -1,12 +1,11 @@
 #!/usr/bin/env python
-
 from circuits.web import Controller
 
-from .helpers import build_opener, HTTPCookieProcessor
-from .helpers import CookieJar
+from .helpers import CookieJar, HTTPCookieProcessor, build_opener
 
 
 class Root(Controller):
+
     def index(self):
         visited = self.cookie.get("visited")
         if visited and visited.value:
@@ -20,10 +19,10 @@ def test(webapp):
     cj = CookieJar()
     opener = build_opener(HTTPCookieProcessor(cj))
 
-    f = opener.open(webapp.server.base)
+    f = opener.open(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
 
-    f = opener.open(webapp.server.base)
+    f = opener.open(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello again!"
