@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-
 from datetime import datetime
-from time import mktime
 from email.utils import parsedate
+from time import mktime
 
 from circuits.web import Controller
 
@@ -21,7 +20,7 @@ class Root(Controller):
 
 
 def test(webapp):
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
     expires = f.headers["Expires"]
@@ -30,7 +29,7 @@ def test(webapp):
 
 
 def test_nocache(webapp):
-    f = urlopen("%s/nocache" % webapp.server.base)
+    f = urlopen("%s/nocache" % webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
 
@@ -39,7 +38,7 @@ def test_nocache(webapp):
     cacheControl = f.headers["Cache-Control"]
 
     now = datetime.utcnow()
-    lastyear = now.replace(year=now.year-1)
+    lastyear = now.replace(year=now.year - 1)
 
     diff = (mktime(parsedate(expires)) - mktime(lastyear.utctimetuple()))
     assert diff < 1.0
