@@ -1,13 +1,12 @@
 #!/usr/bin/env python
-
 from circuits import Component
-from circuits.web import Controller, JSONRPC
+from circuits.web import JSONRPC, Controller
 
-from .jsonrpclib import ServerProxy
 from .helpers import urlopen
+from .jsonrpclib import ServerProxy
 
 
-class Test(Component):
+class App(Component):
 
     def eval(self, s):
         return eval(s)
@@ -21,15 +20,15 @@ class Root(Controller):
 
 def test(webapp):
     rpc = JSONRPC("/rpc")
-    test = Test()
+    test = App()
     rpc.register(webapp)
     test.register(webapp)
 
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
 
-    url = "%s/rpc/" % webapp.server.base
+    url = "%s/rpc" % webapp.server.http.base
     jsonrpc = ServerProxy(url, allow_none=True, encoding='utf-8')
 
     data = jsonrpc.eval("1 + 2")
