@@ -1,18 +1,17 @@
 #!/usr/bin/env python
-
+import re
 import sys
-
-try:
-    from StringIO import StringIO
-except ImportError:
-    from io import StringIO  # NOQA
-
 from socket import gaierror, gethostbyname, gethostname
 
 from circuits.web import Controller, Logger
 
 from .helpers import urlopen
 
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO  # NOQA
+
 
 class DummyLogger(object):
 
@@ -36,7 +35,7 @@ def test_file(webapp):
     logger = Logger(file=logfile)
     logger.register(webapp)
 
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
 
@@ -61,7 +60,11 @@ def test_file(webapp):
     keys = list(d.keys())
 
     for k in keys:
-        assert d[k] in s
+        if d[k] and d[k].startswith("127."):
+            # loopback network: 127.0.0.0/8
+            assert re.search(r"127(\.[0-9]{1,3}){3}", s)
+        else:
+            assert d[k] in s
 
     logfile.close()
     logger.unregister()
@@ -72,7 +75,7 @@ def test_logger(webapp):
     logger = Logger(logger=logobj)
     logger.register(webapp)
 
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
 
@@ -96,7 +99,11 @@ def test_logger(webapp):
     keys = list(d.keys())
 
     for k in keys:
-        assert d[k] in s
+        if d[k] and d[k].startswith("127."):
+            # loopback network: 127.0.0.0/8
+            assert re.search(r"127(\.[0-9]{1,3}){3}", s)
+        else:
+            assert d[k] in s
 
     logger.unregister()
 
@@ -108,7 +115,7 @@ def test_filename(webapp, tmpdir):
 
     logfile = open(logfile, "r")
 
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
 
@@ -133,7 +140,11 @@ def test_filename(webapp, tmpdir):
     keys = list(d.keys())
 
     for k in keys:
-        assert d[k] in s
+        if d[k] and d[k].startswith("127."):
+            # loopback network: 127.0.0.0/8
+            assert re.search(r"127(\.[0-9]{1,3}){3}", s)
+        else:
+            assert d[k] in s
 
     logfile.close()
     logger.unregister()
