@@ -1,15 +1,15 @@
 #!/usr/bin/env python
-
-from .helpers import urlopen, HTTPError
-from circuits.core.handlers import handler
 from circuits.core.components import BaseComponent
+from circuits.core.handlers import handler
+
+from .helpers import HTTPError, urlopen
 
 
 class Root(BaseComponent):
 
     channel = "web"
 
-    @handler("request", filter=True, priority=0.2)
+    @handler("request", priority=0.2)
     def request(self, request, response):
         raise Exception()
 
@@ -17,7 +17,7 @@ class Root(BaseComponent):
 def test(webapp):
     try:
         Root().register(webapp)
-        urlopen(webapp.server.base)
+        urlopen(webapp.server.http.base)
     except HTTPError as e:
         assert e.code == 500
     else:
