@@ -1,9 +1,7 @@
 #!/usr/bin/env python
-
 import os
 from tempfile import mkstemp
 
-from circuits import handler
 from circuits.web import Controller
 
 from .helpers import urlopen
@@ -11,14 +9,14 @@ from .helpers import urlopen
 
 class Root(Controller):
 
-    @handler("started", priority=1.0, channel="*")
-    def _on_started(self, component):
+    def __init__(self, *args, **kwargs):
+        super(Root, self).__init__(self, *args, **kwargs)
+
         fd, self.filename = mkstemp()
         os.write(fd, b"Hello World!")
         os.close(fd)
 
-    @handler("stopped", channel="(")
-    def _on_stopped(self, component):
+    def __del__(self):
         os.remove(self.filename)
 
     def index(self):
@@ -26,6 +24,6 @@ class Root(Controller):
 
 
 def test(webapp):
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
