@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-
-from circuits.web import expose, Controller
+from circuits.web import Controller, expose
 
 from .helpers import urlopen
 
@@ -27,10 +26,10 @@ class Leaf(Controller):
 def test(webapp):
     Leaf().register(webapp)
 
-    f = urlopen(webapp.server.base + "/test.txt")
+    f = urlopen(webapp.server.http.base + "/test.txt")
     s = f.read()
     assert s == b"Hello world!"
 
-    f = urlopen(webapp.server.base + "/test/test.txt")
+    f = urlopen(webapp.server.http.base + "/test/test.txt")
     s = f.read()
     assert s == b"Hello world!"
