@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-
 from circuits.web import Controller
 from circuits.web.wsgi import Application
 
@@ -12,10 +11,11 @@ class Root(Controller):
         yield "Hello "
         yield "World!"
 
+
 application = Application() + Root()
 
 
 def test(webapp):
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
