@@ -1,8 +1,5 @@
 #!/usr/bin/env python
-
 import pytest
-if pytest.PYVER[:2] == (3, 3):
-    pytest.skip("Broken on Python 3.3")
 
 from circuits.web import Server
 from circuits.web.wsgi import Gateway
@@ -40,11 +37,11 @@ def test(apps):
     server.start()
     waiter.wait()
 
-    f = urlopen(server.base)
+    f = urlopen(server.http.base)
     s = f.read()
     assert s == b"Hello World!"
 
-    f = urlopen("{0:s}/foobar/".format(server.base))
+    f = urlopen("{0:s}/foobar/".format(server.http.base))
     s = f.read()
     assert s == b"FooBar!"
 
