@@ -1,9 +1,8 @@
 #!/usr/bin/env python
+from circuits.web import Controller
 
 from .helpers import urlopen
 
-from circuits.web import Controller
-
 
 class Root(Controller):
 
@@ -18,6 +17,6 @@ def application(environ, start_response):
 
 
 def test(webapp):
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b""
