@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-
 from .helpers import urlopen
 
 
@@ -12,6 +11,6 @@ def application(environ, start_response):
 
 
 def test(webapp):
-    f = urlopen(webapp.server.base)
+    f = urlopen(webapp.server.http.base)
     s = f.read()
     assert s == b"Hello World!"
